-- AtlasLoot_Classes

-- loot.lua:
-- Loot tables for AtlasLoot_Classes data

local addonName, addonTable = ...

local AtlasLoot = _G.AtlasLoot

--if we are running with AtlasLoot before v8, cancel
if AtlasLoot and ATLASLOOT_VERSION_NUM then
  return
end

local data = AtlasLoot.ItemDB:Add(addonName)

local MASTERY = "|cFF1144FFMastery"
local DRAENORPERK = "|cFF11FF44Draenor Perk"
local function colorstr(class) return "|c"..RAID_CLASS_COLORS[class].colorStr end
local function coords(class) local c = CLASS_ICON_TCOORDS[class] return ":"..c[1]..":"..c[2]..":"..c[3]..":"..c[4] end
local COLOR_PET_FAMILY = "|cFFFFFFFF"
local COLOR_HORDE = "|cFFE62828"
local COLOR_ALLIANCE = "|cFF2828E6"

local HORDE_RACIAL_DIFF = data:AddDifficulty(COLOR_HORDE.."Horde")
local ALLIANCE_RACIAL_DIFF = data:AddDifficulty(COLOR_ALLIANCE.."Alliance")
local BOTH_RACIAL_DIFF = data:AddDifficulty(COLOR_HORDE.."Horde|cFFFFFFFF+"..COLOR_ALLIANCE.."Alliance")
local DK_DIFF = data:AddDifficulty("Death Knight")
local DK_BLOOD_DIFF = data:AddDifficulty("Blood")
local DK_FROST_DIFF = data:AddDifficulty("Frost")
local DK_UNHOLY_DIFF = data:AddDifficulty("Unholy")
local DK_RUNEFORGING_DIFF = data:AddDifficulty("Runeforging")

local DRUID_DIFF = data:AddDifficulty("Druid")
local DRUID_BALANCE_DIFF = data:AddDifficulty("Balance")
local DRUID_FERAL_DIFF = data:AddDifficulty("Feral")
local DRUID_GUARDIAN_DIFF = data:AddDifficulty("Guardian")
local DRUID_RESTO_DIFF = data:AddDifficulty("Restoration")

local HUNTER_DIFF = data:AddDifficulty("Hunter")
local HUNTER_BM_DIFF = data:AddDifficulty("Beast Mastery")
local HUNTER_MM_DIFF = data:AddDifficulty("Marksmanship")
local HUNTER_SV_DIFF = data:AddDifficulty("Survival")
local HUNTER_PET_FAMILY_DIFF = data:AddDifficulty("Pet Family")
local HUNTER_PET_SPEC_DIFF = data:AddDifficulty("Pet Specialization")

local MAGE_DIFF = data:AddDifficulty("Mage")
local MAGE_ARCANE_DIFF = data:AddDifficulty("Arcane")
local MAGE_FIRE_DIFF = data:AddDifficulty("Fire")
local MAGE_FROST_DIFF = data:AddDifficulty("Frost")

local MONK_DIFF = data:AddDifficulty("Monk")
local MONK_BM_DIFF = data:AddDifficulty("Brewmaster")
local MONK_MW_DIFF = data:AddDifficulty("Mistweaver")
local MONK_WW_DIFF = data:AddDifficulty("Windwalker")

local PALADIN_DIFF = data:AddDifficulty("Paladin")
local PALADIN_HOLY_DIFF = data:AddDifficulty("Holy")
local PALADIN_PROT_DIFF = data:AddDifficulty("Protection")
local PALADIN_RET_DIFF = data:AddDifficulty("Retribution")

local PRIEST_DIFF = data:AddDifficulty("Priest")
local PRIEST_DISC_DIFF = data:AddDifficulty("Discipline")
local PRIEST_HOLY_DIFF = data:AddDifficulty("Holy")
local PRIEST_SHADOW_DIFF = data:AddDifficulty("Shadow")

local ROGUE_DIFF = data:AddDifficulty("Rogue")
local ROGUE_ASS_DIFF = data:AddDifficulty("Assassination")
local ROGUE_COMBAT_DIFF = data:AddDifficulty("Combat")
local ROGUE_SUBTLETY_DIFF = data:AddDifficulty("Subtlety")

local SHAMAN_DIFF = data:AddDifficulty("Shaman")
local SHAMAN_ELE_DIFF = data:AddDifficulty("Elemental")
local SHAMAN_ENH_DIFF = data:AddDifficulty("Enhancement")
local SHAMAN_RESTO_DIFF = data:AddDifficulty("Restoration")

local WARLOCK_DIFF = data:AddDifficulty("Warlock")
local WARLOCK_AFF_DIFF = data:AddDifficulty("Affliction")
local WARLOCK_DEMO_DIFF = data:AddDifficulty("Demonology")
local WARLOCK_DESTRO_DIFF = data:AddDifficulty("Destruction")
local WARLOCK_PET_NORMAL_DIFF = data:AddDifficulty("Normal")
local WARLOCK_PET_GOS_DIFF = data:AddDifficulty("Grimoire of Supremacy")

local WARRIOR_DIFF = data:AddDifficulty("Warrior")
local WARRIOR_ARMS_DIFF = data:AddDifficulty("Arms")
local WARRIOR_FURY_DIFF = data:AddDifficulty("Fury")
local WARRIOR_PROT_DIFF = data:AddDifficulty("Protection")

local SPECIAL_DIFF = data:AddDifficulty("Special")
local PET_DIFF = data:AddDifficulty("Pet")

local GLYPH_DIFF = data:AddDifficulty("Glyph")

local SPELL_ITTYPE = data:AddItemTableType("ClassesSpell")

local CLASSES_CONTENT = data:AddContentType("Classes", {0.0, 0.0, 0.0, 1})
local RACIAL_CONTENT = data:AddContentType("Races", {0.0, 0.0, 0.0, 1})

--also needed to set when setting [ATLASLOOT_IT_HORDE] or [ATLASLOOT_IT_ALLIANCE]
--otherwise it won't show for both factions
local FACTION_INFO_IS_SET_ID = 998
--unused so far
local IGNORE_THIS_BUTTON_ID = 999

data["CLASS_DK"] = {
  name = "Death Knight",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("DEATHKNIGHT"),
      [DK_DIFF] = {
        { 1, 76282 },
        { 2, 76292 },
        { 4, { id = 82246, level = "1" }, },
        { 5, { id = 50842, level = "55" }, },
        { 6, { id = 47541, level = "55" }, },
        { 7, { id = 50977, level = "55" }, },
        { 8, { id = 49576, level = "55" }, },
        { 9, { id = 48266, level = "55" }, },
        { 10, { id = 45477, level = "55" }, },
        { 11, { id = 45462, level = "55" }, },
        { 12, { id = 53428, level = "55" }, },
        { 13, { id = 49998, level = "56" }, },
        { 14, { id = 48263, level = "57" }, },
        { 15, { id = 47528, level = "57" }, },
        { 16, { id = 45524, level = "58" }, },
        { 17, { id = 47476, level = "58" }, },
        { 18, { id = 178819, level = "60" }, },
        { 19, { id = 43265, level = "60" }, },
        { 20, { id = 51986, level = "61" }, },
        { 21, { id = 48792, level = "62" }, },
        { 22, { id = 48265, level = "64" }, },
        { 23, { id = 57330, level = "65" }, },
        { 24, { id = 3714, level = "66" }, },
        { 25, { id = 48707, level = "68" }, },
        { 26, { id = 111673, level = "69" }, },
        { 27, { id = 61999, level = "72" }, },
        { 28, { id = 47568, level = "76" }, },
        { 29, { id = 42650, level = "80" }, },
        { 30, { id = 77575, level = "81" }, },
        { 101, { id = 77606, level = "85" }, },
        { 102, { id = 130736, level = "87" }, },
      },
    },
    {
      name = "Blood",
      CoinTexture = "texture:Interface\\Icons\\spell_deathknight_bloodpresence",
      [DK_DIFF] = {
        { 1, { id = 82246, level = 1 }, },
        { 2, { id = 161608, level = 10 }, },
        { 3, { id = 81136, level = 10 }, },
        { 4, { id = 158298, level = 10 }, },
        { 5, { id = 50842, level = 55 }, },
        { 6, { id = 50034, level = 55 }, },
        { 7, { id = 47541, level = 55 }, },
        { 8, { id = 50977, level = 55 }, },
        { 9, { id = 49576, level = 55 }, },
        { 10, { id = 48266, level = 55 }, },
        { 11, { id = 45477, level = 55 }, },
        { 12, { id = 45462, level = 55 }, },
        { 13, { id = 53428, level = 55 }, },
        { 14, { id = 50029, level = 55 }, },
        { 15, { id = 49998, level = 56 }, },
        { 16, { id = 48263, level = 57 }, },
        { 17, { id = 47528, level = 57 }, },
        { 18, { id = 45524, level = 58 }, },
        { 19, { id = 56222, level = 58 }, },
        { 20, { id = 47476, level = 58 }, },
        { 21, { id = 178819, level = 60 }, },
        { 22, { id = 43265, level = 60 }, },
        { 23, { id = 51986, level = 61 }, },
        { 24, { id = 48792, level = 62 }, },
        { 25, { id = 50371, level = 64 }, },
        { 26, { id = 48982, level = 64 }, },
        { 27, { id = 48265, level = 64 }, },
        { 28, { id = 57330, level = 65 }, },
        { 29, { id = 3714, level = 66 }, },
        { 30, { id = 48707, level = 68 }, },
        { 101, { id = 111673, level = 69 }, },
        { 102, { id = 81164, level = 70 }, },
        { 103, { id = 61999, level = 72 }, },
        { 104, { id = 81127, level = 72 }, },
        { 105, { id = 49028, level = 74 }, },
        { 106, { id = 47568, level = 76 }, },
        { 107, { id = 161797, level = 76 }, },
        { 108, { id = 55233, level = 76 }, },
        { 109, { id = 49222, level = 78 }, },
        { 110, { id = 42650, level = 80 }, },
        { 111, { id = 77513, level = 80, rank = MASTERY }, },
        { 112, { id = 155522, level = 80 }, },
        { 113, { id = 77575, level = 81 }, },
        { 114, { id = 77606, level = 85 }, },
        { 115, { id = 130736, level = 87 }, },
        { 116, { id = 114866, level = 87 }, },
        { 117, { id = 165394, level = 90 }, },
        { 118, { id = 157338, level = "92+", rank = DRAENORPERK }, },
        { 119, { id = 157343, level = "92+", rank = DRAENORPERK }, },
        { 120, { id = 157337, level = "92+", rank = DRAENORPERK }, },
        { 121, { id = 157336, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Frost",
      CoinTexture = "texture:Interface\\Icons\\spell_deathknight_frostpresence",
      [DK_DIFF] = {
        { 1, { id = 674, level = "1" }, },
        { 2, { id = 82246, level = "1" }, },
        { 3, { id = 59057, level = "10" }, },
        { 4, { id = 50842, level = "55" }, },
        { 5, { id = 54637, level = "55" }, },
        { 6, { id = 47541, level = "55" }, },
        { 7, { id = 50977, level = "55" }, },
        { 8, { id = 49576, level = "55" }, },
        { 9, { id = 48266, level = "55" }, },
        { 10, { id = 49143, level = "55" }, },
        { 11, { id = 49184, level = "55" }, },
        { 12, { id = 50887, level = "55" }, },
        { 13, { id = 45477, level = "55" }, },
        { 14, { id = 45462, level = "55" }, },
        { 15, { id = 53428, level = "55" }, },
        { 16, { id = 49998, level = "56" }, },
        { 17, { id = 48263, level = "57" }, },
        { 18, { id = 47528, level = "57" }, },
        { 19, { id = 45524, level = "58" }, },
        { 20, { id = 49020, level = "58" }, },
        { 21, { id = 47476, level = "58" }, },
        { 22, { id = 178819, level = "60" }, },
        { 23, { id = 43265, level = "60" }, },
        { 24, { id = 55610, level = "60" }, },
        { 25, { id = 51986, level = "61" }, },
        { 26, { id = 48792, level = "62" }, },
        { 27, { id = 51128, level = "63" }, },
        { 28, { id = 48265, level = "64" }, },
        { 29, { id = 57330, level = "65" }, },
        { 30, { id = 50385, level = "65" }, },
        { 101, { id = 3714, level = "66" }, },
        { 102, { id = 48707, level = "68" }, },
        { 103, { id = 51271, level = "68" }, },
        { 104, { id = 111673, level = "69" }, },
        { 105, { id = 61999, level = "72" }, },
        { 106, { id = 81333, level = "74" }, },
        { 107, { id = 66192, level = "74" }, },
        { 108, { id = 47568, level = "76" }, },
        { 109, { id = 42650, level = "80" }, },
        { 110, { id = 77514, level = "80", rank = MASTERY }, },
        { 111, { id = 77575, level = "81" }, },
        { 112, { id = 77606, level = "85" }, },
        { 113, { id = 130736, level = "87" }, },
        { 114, { id = 130735, level = "87" }, },
        { 115, { id = 157409, level = "92+", rank = DRAENORPERK }, },
        { 116, { id = 157389, level = "92+", rank = DRAENORPERK }, },
        { 117, { id = 157367, level = "92+", rank = DRAENORPERK }, },
        { 118, { id = 157376, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Unholy",
      CoinTexture = "texture:Interface\\Icons\\spell_deathknight_unholypresence",
      [DK_DIFF] = {
        { 1, { id = 82246, level = "1" }, },
        { 2, { id = 51160, level = "10" }, },
        { 3, { id = 56835, level = "10" }, },
        { 4, { id = 50842, level = "55" }, },
        { 5, { id = 47541, level = "55" }, },
        { 6, { id = 50977, level = "55" }, },
        { 7, { id = 49576, level = "55" }, },
        { 8, { id = 48266, level = "55" }, },
        { 9, { id = 45477, level = "55" }, },
        { 10, { id = 45462, level = "55" }, },
        { 11, { id = 53428, level = "55" }, },
        { 12, { id = 91107, level = "55" }, },
        { 13, { id = 49998, level = "56" }, },
        { 14, { id = 46584, level = "56" }, },
        { 15, { id = 48263, level = "57" }, },
        { 16, { id = 47528, level = "57" }, },
        { 17, { id = 45524, level = "58" }, },
        { 18, { id = 55090, level = "58" }, },
        { 19, { id = 47476, level = "58" }, },
        { 20, { id = 178819, level = "60" }, },
        { 21, { id = 43265, level = "60" }, },
        { 22, { id = 49572, level = "60" }, },
        { 23, { id = 55610, level = "60" }, },
        { 24, { id = 51986, level = "61" }, },
        { 25, { id = 85948, level = "62" }, },
        { 26, { id = 48792, level = "62" }, },
        { 27, { id = 49530, level = "64" }, },
        { 28, { id = 48265, level = "64" }, },
        { 29, { id = 57330, level = "65" }, },
        { 30, { id = 3714, level = "66" }, },
        { 101, { id = 48707, level = "68" }, },
        { 102, { id = 111673, level = "69" }, },
        { 103, { id = 63560, level = "70" }, },
        { 104, { id = 61999, level = "72" }, },
        { 105, { id = 49206, level = "74" }, },
        { 106, { id = 50392, level = "75" }, },
        { 107, { id = 47568, level = "76" }, },
        { 108, { id = 42650, level = "80" }, },
        { 109, { id = 77515, level = "80", rank = MASTERY }, },
        { 110, { id = 77575, level = "81" }, },
        { 111, { id = 77606, level = "85" }, },
        { 112, { id = 130736, level = "87" }, },
        { 113, { id = 165395, level = "90" }, },
        { 114, { id = 157441, level = "92+", rank = DRAENORPERK }, },
        { 115, { id = 157412, level = "92+", rank = DRAENORPERK }, },
        { 116, { id = 157437, level = "92+", rank = DRAENORPERK }, },
        { 117, { id = 157342, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [DK_BLOOD_DIFF] = {
        { 1, { id = 161497, level = "56" }, },
        { 2, { id = 123693, level = "56" }, },
        { 3, { id = 115989, level = "56" }, },
        { 5, { id = 49039, level = "57" }, },
        { 6, { id = 51052, level = "57" }, },
        { 7, { id = 114556, level = "57" }, },
        { 9, { id = 96268, level = "58" }, },
        { 10, { id = 50041, level = "58" }, },
        { 11, { id = 108194, level = "58" }, },
        { 13, { id = 45529, level = "60" }, },
        { 14, { id = 81229, level = "60" }, },
        { 15, { id = 51462, level = "60" }, },
        { 16, { id = 48743, level = "75" }, },
        { 17, { id = 108196, level = "75" }, },
        { 18, { id = 119975, level = "75" }, },
        { 20, { id = 108199, level = "90" }, },
        { 21, { id = 108200, level = "90" }, },
        { 22, { id = 108201, level = "90" }, },
        { 24, { id = 152281, level = "100" }, },
        { 25, { id = 152280, level = "100" }, },
        { 26, { id = 152279, level = "100" }, },
      },
      [DK_FROST_DIFF] = {
        { 1, { id = 161497, level = "56" }, },
        { 2, { id = 123693, level = "56" }, },
        { 3, { id = 115989, level = "56" }, },
        { 5, { id = 49039, level = "57" }, },
        { 6, { id = 51052, level = "57" }, },
        { 7, { id = 114556, level = "57" }, },
        { 9, { id = 96268, level = "58" }, },
        { 10, { id = 50041, level = "58" }, },
        { 11, { id = 108194, level = "58" }, },
        { 13, { id = 45529, level = "60" }, },
        { 14, { id = 81229, level = "60" }, },
        { 15, { id = 51462, level = "60" }, },
        { 16, { id = 48743, level = "75" }, },
        { 17, { id = 108196, level = "75" }, },
        { 18, { id = 119975, level = "75" }, },
        { 20, { id = 108199, level = "90" }, },
        { 21, { id = 108200, level = "90" }, },
        { 22, { id = 108201, level = "90" }, },
        { 24, { id = 152281, level = "100" }, },
        { 25, { id = 152280, level = "100" }, },
        { 26, { id = 152279, level = "100" }, },
      },
      [DK_UNHOLY_DIFF] = {
        { 1, { id = 161497, level = "56" }, },
        { 2, { id = 123693, level = "56" }, },
        { 3, { id = 115989, level = "56" }, },
        { 5, { id = 49039, level = "57" }, },
        { 6, { id = 51052, level = "57" }, },
        { 7, { id = 114556, level = "57" }, },
        { 9, { id = 96268, level = "58" }, },
        { 10, { id = 50041, level = "58" }, },
        { 11, { id = 108194, level = "58" }, },
        { 13, { id = 45529, level = "60" }, },
        { 14, { id = 81229, level = "60" }, },
        { 15, { id = 51462, level = "60" }, },
        { 16, { id = 48743, level = "75" }, },
        { 17, { id = 108196, level = "75" }, },
        { 18, { id = 119975, level = "75" }, },
        { 20, { id = 108199, level = "90" }, },
        { 21, { id = 108200, level = "90" }, },
        { 22, { id = 108201, level = "90" }, },
        { 24, { id = 152281, level = "100" }, },
        { 25, { id = 152280, level = "100" }, },
        { 26, { id = 152279, level = "100" }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majordeathknight",
      [GLYPH_DIFF] = {
        { 1, 159415 },
        { 2, 58623 },
        { 3, 58657 },
        { 4, 58620 },
        { 5, 63330 },
        { 6, 63331 },
        { 7, 58629 },
        { 8, 63333 },
        { 9, 62259 },
        { 10, 159421 },
        { 11, 58671 },
        { 12, 58673 },
        { 13, 159418 },
        { 14, 58631 },
        { 15, 58686 },
        { 16, 59332 },
        { 17, 58635 },
        { 18, 159427 },
        { 19, 146648 },
        { 20, 159428 },
        { 21, 159429 },
        { 22, 58647 },
        { 23, 58618 },
        { 24, 146645 },
        { 25, 159416 },
        { 26, 59327 },
        { 27, 58616 },
        { 28, 58676 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minordeathknight",
      [GLYPH_DIFF] = {
        { 1, 58669 },
        { 2, 59336 },
        { 3, 60200 },
        { 4, 58677 },
        { 5, 58642 },
        { 6, 58680 },
        { 7, 59307 },
        { 8, 59309 },
        { 9, 58640 },
        { 10, 146652 },
        { 11, 63335 },
      },
    },
    {
      name = "Pet Abilities",
      CoinTexture = "texture:Interface\\Icons\\spell_shadow_animatedead",
      [PET_DIFF] = {
        { 1, { id = 62137, rank = "", name = "Avoidance" }, },
        
        { 3, { id = 47468, rank = "", name = "Claw" }, },
        { 4, { id = 47481, rank = "", name = "Gnaw" }, },
        { 5, { id = 47484, rank = "", name = "Huddle" }, },
        { 6, { id = 47482, rank = "", name = "Leap" }, },
        
        { 8, { id = 91778, rank = "Dark Transformation", name = "Sweeping Claws" }, },
        { 9, { id = 91797, rank = "Dark Transformation", name = "Monstrous Blow" }, },
        { 10, { id = 91837, rank = "Dark Transformation", name = "Putrid Bulwark" }, },
        { 11, { id = 91802, rank = "Dark Transformation", name = "Shambling Rush" }, },
      },
    },
    {
      name = "Runeforging",
      CoinTexture = "texture:Interface\\Icons\\spell_deathknight_frozenruneweapon",
      [DK_RUNEFORGING_DIFF] = {
        { 1, { id = 53343, level = 55 }, },
        { 2, { id = 54447, level = 57 }, },
        { 3, { id = 53342, level = 57 }, },
        { 4, { id = 53331, level = 60 }, },
        { 5, { id = 53344, level = 70 }, },
        { 6, { id = 62158, level = 72 }, },
      },
    },
  },
}

data["CLASS_DRUID"] = {
  name = "Druid",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("DRUID"),
      [DRUID_DIFF] = {
        { 1, 76275 },
        { 2, 76300 },
        { 4, { id = 5176, level = "1" }, },
        { 5, { id = 8921, level = "3" }, },
        { 6, { id = 164812, level = "3" }, },
        { 7, { id = 774, level = "4" }, },
        { 8, { id = 768, level = "6" }, },
        { 9, { id = 125972, level = "6" }, },
        { 10, { id = 22568, level = "6" }, },
        { 11, { id = 5215, level = "6" }, },
        { 12, { id = 5221, level = "6" }, },
        { 13, { id = 5487, level = "8" }, },
        { 14, { id = 6795, level = "8" }, },
        { 15, { id = 33917, level = "8" }, },
        { 16, { id = 339, level = "10" }, },
        { 17, { id = 50769, level = "12" }, },
        { 18, { id = 18960, level = "14" }, },
        { 19, { id = 106832, level = "14" }, },
        { 20, { id = 783, level = "16" }, },
        { 21, { id = 164815, level = "18" }, },
        { 22, { id = 1850, level = "24" }, },
        { 23, { id = 5185, level = "26" }, },
        { 24, { id = 16961, level = "30" }, },
        { 25, { id = 20484, level = "56" }, },
        { 26, { id = 2908, level = "60" }, },
        { 27, { id = 1126, level = "62" }, },
        { 28, { id = 22842, level = "68" }, },
        { 29, { id = 33786, level = "78" }, },
        { 30, { id = 106898, level = "84" }, },
      },
    },
    {
      name = "Balance",
      CoinTexture = "texture:Interface\\Icons\\spell_nature_starfall",
      [DRUID_DIFF] = {
        { 1, { id = 5176, level = "1" }, },
        { 2, { id = 164812, level = "3" }, },
        { 3, { id = 8921, level = "3" }, },
        { 4, { id = 774, level = "4" }, },
        { 5, { id = 768, level = "6" }, },
        { 6, { id = 125972, level = "6" }, },
        { 7, { id = 22568, level = "6" }, },
        { 8, { id = 5215, level = "6" }, },
        { 9, { id = 5221, level = "6" }, },
        { 10, { id = 5487, level = "8" }, },
        { 11, { id = 6795, level = "8" }, },
        { 12, { id = 33917, level = "8" }, },
        { 13, { id = 339, level = "10" }, },
        { 14, { id = 108299, level = "10" }, },
        { 15, { id = 112857, level = "10" }, },
        { 16, { id = 2912, level = "10" }, },
        { 17, { id = 50769, level = "12" }, },
        { 18, { id = 78674, level = "12" }, },
        { 19, { id = 18960, level = "14" }, },
        { 20, { id = 106832, level = "14" }, },
        { 21, { id = 24858, level = "16" }, },
        { 22, { id = 783, level = "16" }, },
        { 23, { id = 164815, level = "18" }, },
        { 24, { id = 127663, level = "20" }, },
        { 25, { id = 2782, level = "22" }, },
        { 26, { id = 1850, level = "24" }, },
        { 27, { id = 5185, level = "26" }, },
        { 28, { id = 93399, level = "26" }, },
        { 29, { id = 78675, level = "28" }, },
        { 30, { id = 16961, level = "30" }, },
        { 101, { id = 22812, level = "44" }, },
        { 102, { id = 86104, level = "50" }, },
        { 103, { id = 20484, level = "56" }, },
        { 104, { id = 2908, level = "60" }, },
        { 105, { id = 1126, level = "62" }, },
        { 106, { id = 112071, level = "68" }, },
        { 107, { id = 22842, level = "68" }, },
        { 108, { id = 48505, level = "76" }, },
        { 109, { id = 33786, level = "78" }, },
        { 110, { id = 77492, level = "80", rank = MASTERY }, },
        { 111, { id = 33605, level = "82" }, },
        { 112, { id = 106898, level = "84" }, },
        { 113, { id = 88747, level = "84" }, },
        { 114, { id = 165386, level = "90" }, },
        { 115, { id = 157229, level = "92+", rank = DRAENORPERK }, },
        { 116, { id = 157227, level = "92+", rank = DRAENORPERK }, },
        { 117, { id = 157301, level = "92+", rank = DRAENORPERK }, },
        { 118, { id = 157232, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Feral",
      CoinTexture = "texture:Interface\\Icons\\ability_druid_catform",
      [DRUID_DIFF] = {
        { 1, { id = 157447, level = "1" }, },
        { 2, { id = 166142, level = "1" }, },
        { 3, { id = 5176, level = "1" }, },
        { 4, { id = 164812, level = "3" }, },
        { 5, { id = 8921, level = "3" }, },
        { 6, { id = 774, level = "4" }, },
        { 7, { id = 768, level = "6" }, },
        { 8, { id = 125972, level = "6" }, },
        { 9, { id = 22568, level = "6" }, },
        { 10, { id = 5215, level = "6" }, },
        { 11, { id = 1822, level = "6" }, },
        { 12, { id = 5221, level = "6" }, },
        { 13, { id = 5487, level = "8" }, },
        { 14, { id = 6795, level = "8" }, },
        { 15, { id = 33917, level = "8" }, },
        { 16, { id = 339, level = "10" }, },
        { 17, { id = 33873, level = "10" }, },
        { 18, { id = 5217, level = "10" }, },
        { 19, { id = 50769, level = "12" }, },
        { 20, { id = 18960, level = "14" }, },
        { 21, { id = 106832, level = "14" }, },
        { 22, { id = 783, level = "16" }, },
        { 23, { id = 52610, level = "18" }, },
        { 24, { id = 164815, level = "18" }, },
        { 25, { id = 1079, level = "20" }, },
        { 26, { id = 2782, level = "22" }, },
        { 27, { id = 106785, level = "22" }, },
        { 28, { id = 1850, level = "24" }, },
        { 29, { id = 5185, level = "26" }, },
        { 30, { id = 16974, level = "26" }, },
        { 101, { id = 770, level = "28" }, },
        { 102, { id = 16961, level = "30" }, },
        { 103, { id = 16864, level = "38" }, },
        { 104, { id = 48484, level = "40" }, },
        { 105, { id = 17007, level = "46" }, },
        { 106, { id = 106952, level = "48" }, },
        { 107, { id = 86097, level = "50" }, },
        { 108, { id = 20484, level = "56" }, },
        { 109, { id = 61336, level = "56" }, },
        { 110, { id = 2908, level = "60" }, },
        { 111, { id = 1126, level = "62" }, },
        { 112, { id = 106839, level = "64" }, },
        { 113, { id = 22842, level = "68" }, },
        { 114, { id = 33786, level = "78" }, },
        { 115, { id = 77493, level = "80", rank = MASTERY }, },
        { 116, { id = 22570, level = "82" }, },
        { 117, { id = 106898, level = "84" }, },
        { 118, { id = 165372, level = "90" }, },
        { 119, { id = 157269, level = "92+", rank = DRAENORPERK }, },
        { 120, { id = 157274, level = "92+", rank = DRAENORPERK }, },
        { 121, { id = 157280, level = "92+", rank = DRAENORPERK }, },
        { 122, { id = 157276, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Guardian",
      CoinTexture = "texture:Interface\\Icons\\ability_racial_bearform",
      [DRUID_DIFF] = {
        { 1, { id = 157447, level = "1" }, },
        { 2, { id = 166142, level = "1" }, },
        { 3, { id = 5176, level = "1" }, },
        { 4, { id = 8921, level = "3" }, },
        { 5, { id = 164812, level = "3" }, },
        { 6, { id = 774, level = "4" }, },
        { 7, { id = 768, level = "6" }, },
        { 8, { id = 125972, level = "6" }, },
        { 9, { id = 22568, level = "6" }, },
        { 10, { id = 5215, level = "6" }, },
        { 11, { id = 5221, level = "6" }, },
        { 12, { id = 5487, level = "8" }, },
        { 13, { id = 6795, level = "8" }, },
        { 14, { id = 33917, level = "8" }, },
        { 15, { id = 161608, level = "10" }, },
        { 16, { id = 339, level = "10" }, },
        { 17, { id = 6807, level = "10" }, },
        { 18, { id = 33873, level = "10" }, },
        { 19, { id = 158298, level = "10" }, },
        { 20, { id = 62606, level = "10" }, },
        { 21, { id = 16931, level = "10" }, },
        { 22, { id = 50769, level = "12" }, },
        { 23, { id = 18960, level = "14" }, },
        { 24, { id = 106832, level = "14" }, },
        { 25, { id = 783, level = "16" }, },
        { 26, { id = 164815, level = "18" }, },
        { 27, { id = 2782, level = "22" }, },
        { 28, { id = 1850, level = "24" }, },
        { 29, { id = 5185, level = "26" }, },
        { 30, { id = 770, level = "28" }, },
        { 101, { id = 16961, level = "30" }, },
        { 102, { id = 135288, level = "32" }, },
        { 103, { id = 33745, level = "38" }, },
        { 104, { id = 48484, level = "40" }, },
        { 105, { id = 22812, level = "44" }, },
        { 106, { id = 106952, level = "48" }, },
        { 107, { id = 86096, level = "50" }, },
        { 108, { id = 20484, level = "56" }, },
        { 109, { id = 61336, level = "56" }, },
        { 110, { id = 2908, level = "60" }, },
        { 111, { id = 1126, level = "62" }, },
        { 112, { id = 106839, level = "64" }, },
        { 113, { id = 22842, level = "68" }, },
        { 114, { id = 33786, level = "78" }, },
        { 115, { id = 155783, level = "80", rank = MASTERY }, },
        { 116, { id = 106898, level = "84" }, },
        { 117, { id = 165387, level = "90" }, },
        { 118, { id = 159232, level = "90" }, },
        { 119, { id = 157292, level = "92+", rank = DRAENORPERK }, },
        { 120, { id = 157284, level = "92+", rank = DRAENORPERK }, },
        { 121, { id = 157286, level = "92+", rank = DRAENORPERK }, },
        { 122, { id = 157283, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Restoration",
      CoinTexture = "texture:Interface\\Icons\\spell_nature_healingtouch",
      [DRUID_DIFF] = {
        { 1, { id = 5176, level = "1" }, },
        { 2, { id = 8921, level = "3" }, },
        { 3, { id = 164812, level = "3" }, },
        { 4, { id = 774, level = "4" }, },
        { 5, { id = 768, level = "6" }, },
        { 6, { id = 125972, level = "6" }, },
        { 7, { id = 22568, level = "6" }, },
        { 8, { id = 5215, level = "6" }, },
        { 9, { id = 5221, level = "6" }, },
        { 10, { id = 5487, level = "8" }, },
        { 11, { id = 6795, level = "8" }, },
        { 12, { id = 33917, level = "8" }, },
        { 13, { id = 339, level = "10" }, },
        { 14, { id = 108299, level = "10" }, },
        { 15, { id = 92364, level = "10" }, },
        { 16, { id = 112857, level = "10" }, },
        { 17, { id = 17073, level = "10" }, },
        { 18, { id = 18562, level = "10" }, },
        { 19, { id = 50769, level = "12" }, },
        { 20, { id = 85101, level = "14" }, },
        { 21, { id = 18960, level = "14" }, },
        { 22, { id = 106832, level = "14" }, },
        { 23, { id = 783, level = "16" }, },
        { 24, { id = 8936, level = "18" }, },
        { 25, { id = 164815, level = "18" }, },
        { 26, { id = 88423, level = "22" }, },
        { 27, { id = 1850, level = "24" }, },
        { 28, { id = 5185, level = "26" }, },
        { 29, { id = 48500, level = "28" }, },
        { 30, { id = 132158, level = "30" }, },
        { 101, { id = 16961, level = "30" }, },
        { 102, { id = 33763, level = "36" }, },
        { 103, { id = 113043, level = "38" }, },
        { 104, { id = 22812, level = "44" }, },
        { 105, { id = 86093, level = "50" }, },
        { 106, { id = 20484, level = "56" }, },
        { 107, { id = 2908, level = "60" }, },
        { 108, { id = 1126, level = "62" }, },
        { 109, { id = 102342, level = "64" }, },
        { 110, { id = 22842, level = "68" }, },
        { 111, { id = 740, level = "74" }, },
        { 112, { id = 48438, level = "76" }, },
        { 113, { id = 33786, level = "78" }, },
        { 114, { id = 77495, level = "80", rank = MASTERY }, },
        { 115, { id = 106898, level = "84" }, },
        { 116, { id = 145205, level = "84" }, },
        { 117, { id = 145518, level = "88" }, },
        { 118, { id = 165374, level = "90" }, },
        { 119, { id = 157305, level = "92+", rank = DRAENORPERK }, },
        { 120, { id = 157300, level = "92+", rank = DRAENORPERK }, },
        { 121, { id = 157312, level = "92+", rank = DRAENORPERK }, },
        { 122, { id = 157301, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [DRUID_BALANCE_DIFF] = {
        { 1, { id = 131768, level = "15" }, },
        { 2, { id = 102280, level = "15" }, },
        { 3, { id = 132302, level = "15" }, },
        { 5, { id = 145108, level = "30" }, },
        { 6, { id = 108238, level = "30" }, },
        { 7, { id = 102351, level = "30" }, },
        { 9, { id = 102355, level = "45" }, },
        { 10, { id = 102359, level = "45" }, },
        { 11, { id = 132469, level = "45" }, },
        { 13, { id = 114107, level = "60" }, },
        { 14, { id = 102560, level = "60" }, },
        { 15, { id = 33831, level = "60" }, },
        { 16, { id = 99, level = "75" }, },
        { 17, { id = 102793, level = "75" }, },
        { 18, { id = 5211, level = "75" }, },
        { 20, { id = 108291, level = "90" }, },
        { 21, { id = 108373, level = "90" }, },
        { 22, { id = 124974, level = "90" }, },
        { 24, { id = 152222, level = "100" }, },
        { 25, { id = 152221, level = "100" }, },
        { 26, { id = 152220, level = "100" }, },
      },
      [DRUID_FERAL_DIFF] = {
        { 1, { id = 131768, level = "15" }, },
        { 2, { id = 102280, level = "15" }, },
        { 3, { id = 132302, level = "15" }, },
        { 5, { id = 145108, level = "30" }, },
        { 6, { id = 108238, level = "30" }, },
        { 7, { id = 102351, level = "30" }, },
        { 9, { id = 106707, level = "45" }, },
        { 10, { id = 102359, level = "45" }, },
        { 11, { id = 132469, level = "45" }, },
        { 13, { id = 158476, level = "60" }, },
        { 14, { id = 102543, level = "60" }, },
        { 15, { id = 102703, level = "60" }, },
        { 16, { id = 99, level = "75" }, },
        { 17, { id = 102793, level = "75" }, },
        { 18, { id = 5211, level = "75" }, },
        { 20, { id = 108292, level = "90" }, },
        { 21, { id = 158497, level = "90" }, },
        { 22, { id = 124974, level = "90" }, },
        { 24, { id = 155580, level = "100" }, },
        { 25, { id = 155672, level = "100" }, },
        { 26, { id = 171746, level = "100" }, },
      },
      [DRUID_GUARDIAN_DIFF] = {
        { 1, { id = 131768, level = "15" }, },
        { 2, { id = 102280, level = "15" }, },
        { 3, { id = 132302, level = "15" }, },
        { 5, { id = 145108, level = "30" }, },
        { 6, { id = 108238, level = "30" }, },
        { 7, { id = 102351, level = "30" }, },
        { 9, { id = 106707, level = "45" }, },
        { 10, { id = 102359, level = "45" }, },
        { 11, { id = 132469, level = "45" }, },
        { 13, { id = 158477, level = "60" }, },
        { 14, { id = 102558, level = "60" }, },
        { 15, { id = 102706, level = "60" }, },
        { 16, { id = 99, level = "75" }, },
        { 17, { id = 102793, level = "75" }, },
        { 18, { id = 5211, level = "75" }, },
        { 20, { id = 108293, level = "90" }, },
        { 21, { id = 158501, level = "90" }, },
        { 22, { id = 124974, level = "90" }, },
        { 24, { id = 155578, level = "100" }, },
        { 25, { id = 80313, level = "100" }, },
        { 26, { id = 155835, level = "100" }, },
      },
      [DRUID_RESTO_DIFF] = {
        { 1, { id = 131768, level = "15" }, },
        { 2, { id = 102280, level = "15" }, },
        { 3, { id = 132302, level = "15" }, },
        { 5, { id = 145108, level = "30" }, },
        { 6, { id = 108238, level = "30" }, },
        { 7, { id = 102351, level = "30" }, },
        { 9, { id = 102355, level = "45" }, },
        { 10, { id = 102359, level = "45" }, },
        { 11, { id = 132469, level = "45" }, },
        { 13, { id = 158478, level = "70" }, },
        { 14, { id = 33891, level = "70" }, },
        { 15, { id = 102693, level = "70" }, },
        { 16, { id = 99, level = "75" }, },
        { 17, { id = 102793, level = "75" }, },
        { 18, { id = 5211, level = "75" }, },
        { 20, { id = 108294, level = "90" }, },
        { 21, { id = 158504, level = "90" }, },
        { 22, { id = 124974, level = "90" }, },
        { 24, { id = 155577, level = "100" }, },
        { 25, { id = 155675, level = "100" }, },
        { 26, { id = 155834, level = "100" }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majordruid",
      [GLYPH_DIFF] = {
        { 1, 159432 },
        { 2, 63057 },
        { 3, 121840 },
        { 4, 47180 },
        { 5, 159445 },
        { 6, 48514 },
        { 7, 59219 },
        { 8, 159436 },
        { 9, 54812 },
        { 10, 54760 },
        { 11, 114237 },
        { 12, 94386 },
        { 13, 67598 },
        { 14, 146655 },
        { 15, 54825 },
        { 16, 54831 },
        { 17, 159434 },
        { 18, 159450 },
        { 19, 54811 },
        { 20, 159455 },
        { 21, 171924 },
        { 22, 54821 },
        { 23, 54733 },
        { 24, 116218 },
        { 25, 17076 },
        { 26, 127540 },
        { 27, 116216 },
        { 28, 114222 },
        { 29, 114223 },
        { 30, 116172 },
        { 31, 159444 },
        { 32, 159453 },
        { 33, 62970 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minordruid",
      [GLYPH_DIFF] = {
        { 1, 57856 },
        { 2, 57855 },
        { 3, 114295 },
        { 4, 146656 },
        { 5, 114301 },
        { 6, 107059 },
        { 7, 131113 },
        { 8, 164997 },
        { 9, 114333 },
        { 10, 114280 },
        { 11, 171803 },
        { 12, 146654 },
        { 13, 114338 },
        { 14, 125047 },
        { 15, 159456 },
      },
    },
  },
}

data["CLASS_HUNTER"] = {
  name = "Hunter",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("HUNTER"),
      [HUNTER_DIFF] = {
        { 1, 76250 },
        { 2, 76249 },
        { 4, { id = 3044, level = "1" }, },
        { 5, { id = 883, level = "1" }, },
        { 6, { id = 157443, level = "1" }, },
        { 7, { id = 982, level = "1" }, },
        { 8, { id = 56641, level = "3" }, },
        { 9, { id = 5116, level = "8" }, },
        { 10, { id = 1462, level = "10" }, },
        { 11, { id = 83242, level = "10" }, },
        { 12, { id = 93321, level = "10" }, },
        { 13, { id = 2641, level = "10" }, },
        { 14, { id = 1515, level = "10" }, },
        { 15, { id = 6991, level = "11" }, },
        { 16, { id = 781, level = "14" }, },
        { 17, { id = 6197, level = "16" }, },
        { 18, { id = 136, level = "16" }, },
        { 19, { id = 147362, level = "22" }, },
        { 20, { id = 5118, level = "24" }, },
        { 21, { id = 2643, level = "24" }, },
        { 22, { id = 1499, level = "28" }, },
        { 23, { id = 5384, level = "32" }, },
        { 24, { id = 19801, level = "35" }, },
        { 25, { id = 13813, level = "38" }, },
        { 26, { id = 1543, level = "38" }, },
        { 27, { id = 19506, level = "39" }, },
        { 28, { id = 83243, level = "42" }, },
        { 29, { id = 34477, level = "42" }, },
        { 30, { id = 13809, level = "46" }, },
        { 101, { id = 77769, level = "48" }, },
        { 102, { id = 20736, level = "52" }, },
        { 103, { id = 13159, level = "56" }, },
        { 104, { id = 83244, level = "62" }, },
        { 105, { id = 53271, level = "74" }, },
        { 106, { id = 19263, level = "78" }, },
        { 107, { id = 83245, level = "82" }, },
        { 108, { id = 172106, level = "84" }, },
        { 109, { id = 51753, level = "85" }, },
      },
    },
    {
      name = "Beast Mastery",
      CoinTexture = "texture:Interface\\Icons\\ability_hunter_bestialdiscipline",
      [HUNTER_DIFF] = {
        { 1, { id = 3044, level = "1" }, },
        { 2, { id = 883, level = "1" }, },
        { 3, { id = 157443, level = "1" }, },
        { 4, { id = 982, level = "1" }, },
        { 5, { id = 56641, level = "3" }, },
        { 6, { id = 5116, level = "8" }, },
        { 7, { id = 1462, level = "10" }, },
        { 8, { id = 83242, level = "10" }, },
        { 9, { id = 93321, level = "10" }, },
        { 10, { id = 2641, level = "10" }, },
        { 11, { id = 34026, level = "10" }, },
        { 12, { id = 1515, level = "10" }, },
        { 13, { id = 6991, level = "11" }, },
        { 14, { id = 781, level = "14" }, },
        { 15, { id = 6197, level = "16" }, },
        { 16, { id = 136, level = "16" }, },
        { 17, { id = 34954, level = "20" }, },
        { 18, { id = 147362, level = "22" }, },
        { 19, { id = 5118, level = "24" }, },
        { 20, { id = 115939, level = "24" }, },
        { 21, { id = 2643, level = "24" }, },
        { 22, { id = 1499, level = "28" }, },
        { 23, { id = 19623, level = "30" }, },
        { 24, { id = 5384, level = "32" }, },
        { 25, { id = 82692, level = "32" }, },
        { 26, { id = 53351, level = "35" }, },
        { 27, { id = 19801, level = "35" }, },
        { 28, { id = 13813, level = "38" }, },
        { 29, { id = 1543, level = "38" }, },
        { 30, { id = 19506, level = "39" }, },
        { 101, { id = 19574, level = "40" }, },
        { 102, { id = 83243, level = "42" }, },
        { 103, { id = 34477, level = "42" }, },
        { 104, { id = 53260, level = "43" }, },
        { 105, { id = 13809, level = "46" }, },
        { 106, { id = 77769, level = "48" }, },
        { 107, { id = 20736, level = "52" }, },
        { 108, { id = 13159, level = "56" }, },
        { 109, { id = 56315, level = "58" }, },
        { 110, { id = 83244, level = "62" }, },
        { 111, { id = 53253, level = "63" }, },
        { 112, { id = 53270, level = "69" }, },
        { 113, { id = 53271, level = "74" }, },
        { 114, { id = 19263, level = "78" }, },
        { 115, { id = 76657, level = "80", rank = MASTERY }, },
        { 116, { id = 77767, level = "81" }, },
        { 117, { id = 83245, level = "82" }, },
        { 118, { id = 172106, level = "84" }, },
        { 119, { id = 51753, level = "85" }, },
        { 120, { id = 165389, level = "90" }, },
        { 121, { id = 157715, level = "92+", rank = DRAENORPERK }, },
        { 122, { id = 157718, level = "92+", rank = DRAENORPERK }, },
        { 123, { id = 157714, level = "92+", rank = DRAENORPERK }, },
        { 124, { id = 157705, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Marksmanship",
      CoinTexture = "texture:Interface\\Icons\\ability_hunter_focusedaim",
      [HUNTER_DIFF] = {
        { 1, { id = 3044, level = "1" }, },
        { 2, { id = 883, level = "1" }, },
        { 3, { id = 157443, level = "1" }, },
        { 4, { id = 982, level = "1" }, },
        { 5, { id = 56641, level = "3" }, },
        { 6, { id = 5116, level = "8" }, },
        { 7, { id = 19434, level = "10" }, },
        { 8, { id = 1462, level = "10" }, },
        { 9, { id = 83242, level = "10" }, },
        { 10, { id = 93321, level = "10" }, },
        { 11, { id = 2641, level = "10" }, },
        { 12, { id = 1515, level = "10" }, },
        { 13, { id = 6991, level = "11" }, },
        { 14, { id = 781, level = "14" }, },
        { 15, { id = 6197, level = "16" }, },
        { 16, { id = 136, level = "16" }, },
        { 17, { id = 34483, level = "20" }, },
        { 18, { id = 147362, level = "22" }, },
        { 19, { id = 5118, level = "24" }, },
        { 20, { id = 2643, level = "24" }, },
        { 21, { id = 1499, level = "28" }, },
        { 22, { id = 5384, level = "32" }, },
        { 23, { id = 53351, level = "35" }, },
        { 24, { id = 19801, level = "35" }, },
        { 25, { id = 13813, level = "38" }, },
        { 26, { id = 1543, level = "38" }, },
        { 27, { id = 19506, level = "39" }, },
        { 28, { id = 83243, level = "42" }, },
        { 29, { id = 34477, level = "42" }, },
        { 30, { id = 35110, level = "45" }, },
        { 101, { id = 13809, level = "46" }, },
        { 102, { id = 77769, level = "48" }, },
        { 103, { id = 20736, level = "52" }, },
        { 104, { id = 3045, level = "54" }, },
        { 105, { id = 13159, level = "56" }, },
        { 106, { id = 53209, level = "60" }, },
        { 107, { id = 83244, level = "62" }, },
        { 108, { id = 53271, level = "74" }, },
        { 109, { id = 19263, level = "78" }, },
        { 110, { id = 76659, level = "80", rank = MASTERY }, },
        { 111, { id = 83245, level = "82" }, },
        { 112, { id = 172106, level = "84" }, },
        { 113, { id = 51753, level = "85" }, },
        { 114, { id = 165378, level = "90" }, },
        { 115, { id = 157724, level = "92+", rank = DRAENORPERK }, },
        { 116, { id = 157718, level = "92+", rank = DRAENORPERK }, },
        { 117, { id = 157707, level = "92+", rank = DRAENORPERK }, },
        { 118, { id = 157726, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Survival",
      CoinTexture = "texture:Interface\\Icons\\ability_hunter_camouflage",
      [HUNTER_DIFF] = {
        { 1, { id = 3044, level = "1" }, },
        { 2, { id = 883, level = "1" }, },
        { 3, { id = 157443, level = "1" }, },
        { 4, { id = 982, level = "1" }, },
        { 5, { id = 56641, level = "3" }, },
        { 6, { id = 5116, level = "8" }, },
        { 7, { id = 1462, level = "10" }, },
        { 8, { id = 83242, level = "10" }, },
        { 9, { id = 93321, level = "10" }, },
        { 10, { id = 2641, level = "10" }, },
        { 11, { id = 53301, level = "10" }, },
        { 12, { id = 164856, level = "10" }, },
        { 13, { id = 1515, level = "10" }, },
        { 14, { id = 63458, level = "10" }, },
        { 15, { id = 6991, level = "11" }, },
        { 16, { id = 781, level = "14" }, },
        { 17, { id = 6197, level = "16" }, },
        { 18, { id = 136, level = "16" }, },
        { 19, { id = 147362, level = "22" }, },
        { 20, { id = 5118, level = "24" }, },
        { 21, { id = 2643, level = "24" }, },
        { 22, { id = 1499, level = "28" }, },
        { 23, { id = 5384, level = "32" }, },
        { 24, { id = 19801, level = "35" }, },
        { 25, { id = 13813, level = "38" }, },
        { 26, { id = 1543, level = "38" }, },
        { 27, { id = 19506, level = "39" }, },
        { 28, { id = 83243, level = "42" }, },
        { 29, { id = 34477, level = "42" }, },
        { 30, { id = 13809, level = "46" }, },
        { 101, { id = 77769, level = "48" }, },
        { 102, { id = 3674, level = "50" }, },
        { 103, { id = 20736, level = "52" }, },
        { 104, { id = 19387, level = "55" }, },
        { 105, { id = 13159, level = "56" }, },
        { 106, { id = 83244, level = "62" }, },
        { 107, { id = 87935, level = "68" }, },
        { 108, { id = 53271, level = "74" }, },
        { 109, { id = 19263, level = "78" }, },
        { 110, { id = 76658, level = "80", rank = MASTERY }, },
        { 111, { id = 77767, level = "81" }, },
        { 112, { id = 83245, level = "82" }, },
        { 113, { id = 172106, level = "84" }, },
        { 114, { id = 51753, level = "85" }, },
        { 115, { id = 165396, level = "90" }, },
        { 116, { id = 157748, level = "92+", rank = DRAENORPERK }, },
        { 117, { id = 157718, level = "92+", rank = DRAENORPERK }, },
        { 118, { id = 157752, level = "92+", rank = DRAENORPERK }, },
        { 119, { id = 157751, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [HUNTER_BM_DIFF] = {
        { 1, { id = 109215, level = "15" }, },
        { 2, { id = 109298, level = "15" }, },
        { 3, { id = 118675, level = "15" }, },
        { 5, { id = 109248, level = "30" }, },
        { 6, { id = 19386, level = "30" }, },
        { 7, { id = 19577, level = "30" }, },
        { 9, { id = 109304, level = "45" }, },
        { 10, { id = 109260, level = "45" }, },
        { 11, { id = 109212, level = "45" }, },
        { 13, { id = 177667, level = "60" }, },
        { 14, { id = 120679, level = "60" }, },
        { 15, { id = 109306, level = "60" }, },
        { 16, { id = 131894, level = "75" }, },
        { 17, { id = 130392, level = "75" }, },
        { 18, { id = 121818, level = "75" }, },
        { 20, { id = 117050, level = "90" }, },
        { 21, { id = 109259, level = "90" }, },
        { 22, { id = 120360, level = "90" }, },
        { 24, { id = 162534, level = "100" }, },
        { 25, { id = 152245, level = "100" }, },
        { 26, { id = 152244, level = "100" }, },
      },
      [HUNTER_MM_DIFF] = {
        { 1, { id = 109215, level = "15" }, },
        { 2, { id = 109298, level = "15" }, },
        { 3, { id = 118675, level = "15" }, },
        { 5, { id = 109248, level = "30" }, },
        { 6, { id = 19386, level = "30" }, },
        { 7, { id = 19577, level = "30" }, },
        { 9, { id = 109304, level = "45" }, },
        { 10, { id = 109260, level = "45" }, },
        { 11, { id = 109212, level = "45" }, },
        { 13, { id = 177667, level = "60" }, },
        { 14, { id = 120679, level = "60" }, },
        { 15, { id = 109306, level = "60" }, },
        { 16, { id = 131894, level = "75" }, },
        { 17, { id = 130392, level = "75" }, },
        { 18, { id = 121818, level = "75" }, },
        { 20, { id = 117050, level = "90" }, },
        { 21, { id = 109259, level = "90" }, },
        { 22, { id = 120360, level = "90" }, },
        { 24, { id = 162534, level = "100" }, },
        { 25, { id = 163485, level = "100" }, },
        { 26, { id = 155228, level = "100" }, },
      },
      [HUNTER_SV_DIFF] = {
        { 1, { id = 109215, level = "15" }, },
        { 2, { id = 109298, level = "15" }, },
        { 3, { id = 118675, level = "15" }, },
        { 5, { id = 109248, level = "30" }, },
        { 6, { id = 19386, level = "30" }, },
        { 7, { id = 19577, level = "30" }, },
        { 9, { id = 109304, level = "45" }, },
        { 10, { id = 109260, level = "45" }, },
        { 11, { id = 109212, level = "45" }, },
        { 13, { id = 177667, level = "60" }, },
        { 14, { id = 120679, level = "60" }, },
        { 15, { id = 109306, level = "60" }, },
        { 16, { id = 131894, level = "75" }, },
        { 17, { id = 130392, level = "75" }, },
        { 18, { id = 121818, level = "75" }, },
        { 20, { id = 117050, level = "90" }, },
        { 21, { id = 109259, level = "90" }, },
        { 22, { id = 120360, level = "90" }, },
        { 24, { id = 162534, level = "100" }, },
        { 25, { id = 152245, level = "100" }, },
        { 26, { id = 155228, level = "100" }, },
      },
      [SPECIAL_DIFF] = {
        { 1, { id = 155228, rank = "|cFFFFFF20Learned Abilities:" }, },
        { 2, { id = 160198, }, },
        { 3, { id = 160199, }, },
        { 4, { id = 160200, }, },
        { 5, { id = 160203, }, },
        { 6, { id = 160205, }, },
        { 7, { id = 160206, }, },
        { 8, { id = 172967, }, },
        { 9, { id = 172968, }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majorhunter",
      [GLYPH_DIFF] = {
        { 1, 20895 },
        { 2, 109263 },
        { 3, 119449 },
        { 4, 119447 },
        { 5, 56850 },
        { 6, 56844 },
        { 7, 123632 },
        { 8, 119410 },
        { 9, 148475 },
        { 10, 119403 },
        { 11, 56845 },
        { 12, 56847 },
        { 13, 132106 },
        { 14, 63068 },
        { 15, 19573 },
        { 16, 56833 },
        { 17, 83495 },
        { 18, 56829 },
        { 19, 53299 },
        { 20, 19560 },
        { 21, 159469 },
        { 22, 159470 },
        { 23, 119407 },
        { 24, 146657 },
        { 25, 119384 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minorhunter",
      [GLYPH_DIFF] = {
        { 1, 125042 },
        { 2, 119462 },
        { 3, 57904 },
        { 4, 122492 },
        { 5, 126746 },
        { 6, 57903 },
        { 7, 57870 },
        { 8, 159459 },
        { 9, 57866 },
        { 10, 57902 },
        { 11, 119464 },
      },
    },
    {
      name = "Pet Abilities",
      CoinTexture = "texture:Interface\\Icons\\ability_druid_ferociousbite",
      [HUNTER_PET_FAMILY_DIFF] = {
        { 1, { id = 65220, rank = "", name = "Avoidance" }, },
        { 2, { id = 20782, rank = "Passive", name = "Combat Experience" }, },
        { 3, { id = 17253, rank = "", name = "Bite" }, },
        { 4, { id = 16827, rank = "", name = "Claw" }, },
        { 5, { id = 49966, rank = "", name = "Smack" }, },
        { 6, { id = 2649, rank = "", name = "Growl" }, },

        { 8, { id = 50519, rank = COLOR_PET_FAMILY.."Bat" }, },
        { 9, { id = 50256, rank = COLOR_PET_FAMILY.."Bear" }, },
        { 10, { id = 94019, rank = COLOR_PET_FAMILY.."Bear" }, },
        { 11, { id = 90339, rank = COLOR_PET_FAMILY.."Beetle" }, },
        { 12, { id = 94022, rank = COLOR_PET_FAMILY.."Bird of Prey" }, },
        { 13, { id = 159735, rank = COLOR_PET_FAMILY.."Bird of Prey" }, },
        { 14, { id = 35290, rank = COLOR_PET_FAMILY.."Boar" }, },
        { 15, { id = 24423, rank = COLOR_PET_FAMILY.."Carrion Bird" }, },
        { 16, { id = 24450, rank = COLOR_PET_FAMILY.."Cat" }, },
        { 17, { id = 93435, rank = COLOR_PET_FAMILY.."Cat" }, },
        { 18, { id = 54644, rank = COLOR_PET_FAMILY.."Chimaera" }, },
        { 19, { id = 159736, rank = COLOR_PET_FAMILY.."Chimaera" }, },
        { 20, { id = 92380, rank = COLOR_PET_FAMILY.."Chimaera |cFF1144FF(AOE)" }, },
        { 21, { id = 160057, rank = COLOR_PET_FAMILY.."Clefthoof" }, },
        { 22, { id = 57386, rank = COLOR_PET_FAMILY.."Clefthoof" }, },
        { 23, { id = 58604, rank = COLOR_PET_FAMILY.."Core Hound" }, },
        { 24, { id = 90355, rank = COLOR_PET_FAMILY.."Core Hound" }, },
        { 25, { id = 159788, rank = COLOR_PET_FAMILY.."Core Hound" }, },
        { 26, { id = 159926, rank = COLOR_PET_FAMILY.."Crab" }, },
        { 27, { id = 126259, rank = COLOR_PET_FAMILY.."Crane" }, },
        { 28, { id = 159931, rank = COLOR_PET_FAMILY.."Crane" }, },
        { 29, { id = 50433, rank = COLOR_PET_FAMILY.."Crocolisk" }, },
        { 30, { id = 54680, rank = COLOR_PET_FAMILY.."Devilsaur" }, },
        { 101, { id = 90309, rank = COLOR_PET_FAMILY.."Devilsaur" }, },
        { 102, { id = 159953, rank = COLOR_PET_FAMILY.."Devilsaur" }, },
        { 103, { id = 137798, rank = COLOR_PET_FAMILY.."Direhorn" }, },
        { 104, { id = 159988, rank = COLOR_PET_FAMILY.."Dog" }, },
        { 105, { id = 34889, rank = COLOR_PET_FAMILY.."Dragonhawk" }, },
        { 106, { id = 90347, rank = COLOR_PET_FAMILY.."Fox" }, },
        { 107, { id = 160011, rank = COLOR_PET_FAMILY.."Fox" }, },
        { 108, { id = 160014, rank = COLOR_PET_FAMILY.."Goat" }, },
        { 109, { id = 160017, rank = COLOR_PET_FAMILY.."Gorilla" }, },
        { 110, { id = 160039, rank = COLOR_PET_FAMILY.."Hydra" }, },
        { 111, { id = 128432, rank = COLOR_PET_FAMILY.."Hyena" }, },
        { 112, { id = 160044, rank = COLOR_PET_FAMILY.."Monkey" }, },
        { 113, { id = 159956, rank = COLOR_PET_FAMILY.."Moth" }, },
        { 114, { id = 160045, rank = COLOR_PET_FAMILY.."Porcupine" }, },
        { 115, { id = 126364, rank = COLOR_PET_FAMILY.."Porcupine" }, },
        { 116, { id = 160049, rank = COLOR_PET_FAMILY.."Quilen" }, },
        { 117, { id = 126373, rank = COLOR_PET_FAMILY.."Quilen" }, },
        { 118, { id = 126393, rank = COLOR_PET_FAMILY.."Quilen" }, },
        { 119, { id = 160052, rank = COLOR_PET_FAMILY.."Raptor" }, },
        { 120, { id = 50518, rank = COLOR_PET_FAMILY.."Ravager" }, },
        { 121, { id = 160018, rank = COLOR_PET_FAMILY.."Riverbeast" }, },
        { 122, { id = 160007, rank = COLOR_PET_FAMILY.."Rylak" }, },
        { 123, { id = 160003, rank = COLOR_PET_FAMILY.."Rylak" }, },
        { 124, { id = 160060, rank = COLOR_PET_FAMILY.."Scorpid" }, },
        { 125, { id = 128433, rank = COLOR_PET_FAMILY.."Serpent" }, },
        { 126, { id = 90363, rank = COLOR_PET_FAMILY.."Shale Spider" }, },
        { 127, { id = 160063, rank = COLOR_PET_FAMILY.."Shale Spider" }, },
        { 128, { id = 160065, rank = COLOR_PET_FAMILY.."Silithid" }, },
        { 129, { id = 90364, rank = COLOR_PET_FAMILY.."Silithid" }, },
        { 130, { id = 160067, rank = COLOR_PET_FAMILY.."Spider" }, },
        { 201, { id = 90361, rank = COLOR_PET_FAMILY.."Spirit Beast" }, },
        { 202, { id = 90328, rank = COLOR_PET_FAMILY.."Spirit Beast" }, },
        { 203, { id = 128997, rank = COLOR_PET_FAMILY.."Spirit Beast" }, },
        { 204, { id = 135678, rank = COLOR_PET_FAMILY.."Sporebat" }, },
        { 205, { id = 173035, rank = COLOR_PET_FAMILY.."Stag" }, },
        { 206, { id = 160073, rank = COLOR_PET_FAMILY.."Tallstrider" }, },
        { 207, { id = 26064, rank = COLOR_PET_FAMILY.."Turtle" }, },
        { 208, { id = 35346, rank = COLOR_PET_FAMILY.."Warp Stalker" }, },
        { 209, { id = 160074, rank = COLOR_PET_FAMILY.."Wasp" }, },
        { 210, { id = 126311, rank = COLOR_PET_FAMILY.."Water Strider" }, },
        { 211, { id = 126309, rank = COLOR_PET_FAMILY.."Water Strider" }, },
        { 212, { id = 24844, rank = COLOR_PET_FAMILY.."Wind Serpent" }, },
        { 213, { id = 24604, rank = COLOR_PET_FAMILY.."Wolf" }, },
        { 214, { id = 160077, rank = COLOR_PET_FAMILY.."Worm" }, },
        { 215, { id = 93433, rank = COLOR_PET_FAMILY.."Worm |cFF1144FF(AOE)" }, },
      },
      [HUNTER_PET_SPEC_DIFF] = {
        { 1, { id = 61684, rank = "" }, },
        { 2, { id = 55709, rank = "" }, },
        { 3, { id = 53184, rank = "Ferocity Passive" }, },

        { 5, { id = 61685, rank = "" }, },
        { 6, { id = 53478, rank = "" }, },
        { 7, { id = 63900, rank = "" }, },
        { 8, { id = 53482, rank = "Tenacity Passive" }, },
        { 9, { id = 61688, rank = "Tenacity Passive" }, },

        { 11, { id = 53490, rank = "" }, },
        { 12, { id = 61684, rank = "" }, },
        { 13, { id = 53480, rank = "" }, },
        { 14, { id = 53497, rank = "Cunning Passive" }, },
        { 15, { id = 19596, rank = "Cunning Passive" }, },
      },
    },
  },
}

data["CLASS_MAGE"] = {
  name = "Mage",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("MAGE"),
      [MAGE_DIFF] = {
        { 1, 76276 },
        { 2, 76298 },
        { 4, { id = 44614, level = "1" }, },
        { 5, { id = 5019, level = "1" }, },
        { 6, { id = 122, level = "3" }, },
        { 7, { id = 2136, level = "5" }, },
        { 8, { id = 1953, level = "7" }, },
        { 9, { id = 2139, level = "8" }, },
        { 10, { id = 118, level = "14" }, },
        { 11, { id = 45438, level = "15" }, },
        { 12, { id = 3565, level = "17" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 13, { id = 32271, level = "17" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 14, { id = 3562, level = "17" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 15, { id = 3567, level = "17" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 16, { id = 32272, level = "17" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 17, { id = 3561, level = "17" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 18, { id = 49359, level = "17" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 19, { id = 3566, level = "17" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 20, { id = 3563, level = "17" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 21, { id = 120, level = "28" }, },
        { 22, { id = 475, level = "29" }, },
        { 23, { id = 130, level = "32" }, },
        { 24, { id = 42955, level = "38" }, },
        { 25, { id = 11419, level = "42" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 26, { id = 32266, level = "42" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 27, { id = 11416, level = "42" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 28, { id = 11417, level = "42" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 29, { id = 32267, level = "42" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 30, { id = 10059, level = "42" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 101, { id = 49360, level = "42" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 102, { id = 11420, level = "42" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 103, { id = 11418, level = "42" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 104, { id = 49361, level = "52" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 105, { id = 49358, level = "52" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 106, { id = 66, level = "56" }, },
        { 107, { id = 1459, level = "58" }, },
        { 108, { id = 161372, level = "60" }, },
        { 109, { id = 61721, level = "60" }, },
        { 110, { id = 28271, level = "60" }, },
        { 111, { id = 161355, level = "60" }, },
        { 112, { id = 126819, level = "60" }, },
        { 113, { id = 61305, level = "60" }, },
        { 114, { id = 161354, level = "60" }, },
        { 115, { id = 61780, level = "60" }, },
        { 116, { id = 28272, level = "60" }, },
        { 117, { id = 161353, level = "60" }, },
        { 118, { id = 35715, level = "62" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 119, { id = 33690, level = "62" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 120, { id = 30449, level = "64" }, },
        { 121, { id = 35717, level = "66" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 122, { id = 33691, level = "66" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 123, { id = 120145, level = "71" }, },
        { 124, { id = 53140, level = "71" }, },
        { 125, { id = 43987, level = "72" }, },
        { 126, { id = 120146, level = "74" }, },
        { 127, { id = 117957, level = "74" }, },
        { 128, { id = 53142, level = "74" }, },
        { 129, { id = 61316, level = "80" }, },
        { 130, { id = 80353, level = "84" }, },
        { 201, { id = 88345, level = "85" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 202, { id = 88346, level = "85" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 203, { id = 88342, level = "85" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 204, { id = 88344, level = "85" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 205, { id = 159916, level = "87" }, },
        { 206, { id = 132626, level = "90" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 207, { id = 132620, level = "90" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 208, { id = 132627, level = "90" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 209, { id = 132621, level = "90" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 210, { id = 176246, level = "92" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 211, { id = 176244, level = "92" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 212, { id = 176248, level = "92" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 213, { id = 176242, level = "92" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
      },
    },
    {
      name = "Arcane",
      CoinTexture = "texture:Interface\\Icons\\spell_holy_magicalsentry",
      [MAGE_DIFF] = {
        { 1, { id = 44614, level = "1" }, },
        { 2, { id = 5019, level = "1" }, },
        { 3, { id = 122, level = "3" }, },
        { 4, { id = 2136, level = "5" }, },
        { 5, { id = 1953, level = "7" }, },
        { 6, { id = 2139, level = "8" }, },
        { 7, { id = 30451, level = "10" }, },
        { 8, { id = 114664, level = "10" }, },
        { 9, { id = 44425, level = "12" }, },
        { 10, { id = 118, level = "14" }, },
        { 11, { id = 45438, level = "15" }, },
        { 12, { id = 1449, level = "18" }, },
        { 13, { id = 12043, level = "22" }, },
        { 14, { id = 5143, level = "24" }, },
        { 15, { id = 120, level = "28" }, },
        { 16, { id = 475, level = "29" }, },
        { 17, { id = 130, level = "32" }, },
        { 18, { id = 31589, level = "36" }, },
        { 19, { id = 42955, level = "38" }, },
        { 20, { id = 12051, level = "40" }, },
        { 21, { id = 66, level = "56" }, },
        { 22, { id = 1459, level = "58" }, },
        { 23, { id = 12042, level = "62" }, },
        { 24, { id = 30449, level = "64" }, },
        { 25, { id = 43987, level = "72" }, },
        { 26, { id = 117957, level = "74" }, },
        { 27, { id = 61316, level = "80" }, },
        { 28, { id = 6117, level = "80" }, },
        { 29, { id = 76547, level = "80", rank = MASTERY }, },
        { 30, { id = 80353, level = "84" }, },
        { 101, { id = 159916, level = "87" }, },
        { 102, { id = 165359, level = "90" }, },
        { 103, { id = 157595, level = "92+", rank = DRAENORPERK }, },
        { 104, { id = 157604, level = "92+", rank = DRAENORPERK }, },
        { 105, { id = 157606, level = "92+", rank = DRAENORPERK }, },
        { 106, { id = 157614, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Fire",
      CoinTexture = "texture:Interface\\Icons\\spell_fire_firebolt02",
      [MAGE_DIFF] = {
        { 1, { id = 44614, level = "1" }, },
        { 2, { id = 5019, level = "1" }, },
        { 3, { id = 122, level = "3" }, },
        { 4, { id = 2136, level = "5" }, },
        { 5, { id = 1953, level = "7" }, },
        { 6, { id = 2139, level = "8" }, },
        { 7, { id = 11366, level = "10" }, },
        { 8, { id = 133, level = "12" }, },
        { 9, { id = 118, level = "14" }, },
        { 10, { id = 45438, level = "15" }, },
        { 11, { id = 2948, level = "22" }, },
        { 12, { id = 108853, level = "24" }, },
        { 13, { id = 120, level = "28" }, },
        { 14, { id = 475, level = "29" }, },
        { 15, { id = 130, level = "32" }, },
        { 16, { id = 30482, level = "34" }, },
        { 17, { id = 117216, level = "36" }, },
        { 18, { id = 42955, level = "38" }, },
        { 19, { id = 2120, level = "44" }, },
        { 20, { id = 66, level = "56" }, },
        { 21, { id = 1459, level = "58" }, },
        { 22, { id = 31661, level = "62" }, },
        { 23, { id = 30449, level = "64" }, },
        { 24, { id = 33691, level = "66" }, },
        { 25, { id = 35717, level = "66" }, },
        { 26, { id = 43987, level = "72" }, },
        { 27, { id = 117957, level = "74" }, },
        { 28, { id = 11129, level = "77" }, },
        { 29, { id = 61316, level = "80" }, },
        { 30, { id = 12846, level = "80", rank = MASTERY }, },
        { 101, { id = 80353, level = "84" }, },
        { 102, { id = 159916, level = "87" }, },
        { 103, { id = 165357, level = "90" }, },
        { 104, { id = 157642, level = "92+", rank = DRAENORPERK }, },
        { 105, { id = 157621, level = "92+", rank = DRAENORPERK }, },
        { 106, { id = 157629, level = "92+", rank = DRAENORPERK }, },
        { 107, { id = 157632, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Frost",
      CoinTexture = "texture:Interface\\Icons\\spell_frost_frostbolt02",
      [MAGE_DIFF] = {
        { 1, { id = 44614, level = "1" }, },
        { 2, { id = 5019, level = "1" }, },
        { 3, { id = 122, level = "3" }, },
        { 4, { id = 2136, level = "5" }, },
        { 5, { id = 1953, level = "7" }, },
        { 6, { id = 2139, level = "8" }, },
        { 7, { id = 31687, level = "10" }, },
        { 8, { id = 116, level = "12" }, },
        { 9, { id = 118, level = "14" }, },
        { 10, { id = 45438, level = "15" }, },
        { 11, { id = 12982, level = "16" }, },
        { 12, { id = 30455, level = "22" }, },
        { 13, { id = 112965, level = "24" }, },
        { 14, { id = 120, level = "28" }, },
        { 15, { id = 475, level = "29" }, },
        { 16, { id = 130, level = "32" }, },
        { 17, { id = 12472, level = "36" }, },
        { 18, { id = 42955, level = "38" }, },
        { 19, { id = 10, level = "52" }, },
        { 20, { id = 7302, level = "54" }, },
        { 21, { id = 66, level = "56" }, },
        { 22, { id = 1459, level = "58" }, },
        { 23, { id = 84714, level = "62" }, },
        { 24, { id = 30449, level = "64" }, },
        { 25, { id = 44572, level = "66" }, },
        { 26, { id = 43987, level = "72" }, },
        { 27, { id = 117957, level = "74" }, },
        { 28, { id = 44549, level = "77" }, },
        { 29, { id = 61316, level = "80" }, },
        { 30, { id = 76613, level = "80", rank = MASTERY }, },
        { 101, { id = 80353, level = "84" }, },
        { 102, { id = 159916, level = "87" }, },
        { 103, { id = 165360, level = "90" }, },
        { 104, { id = 157646, level = "92+", rank = DRAENORPERK }, },
        { 105, { id = 157727, level = "92+", rank = DRAENORPERK }, },
        { 106, { id = 157721, level = "92+", rank = DRAENORPERK }, },
        { 107, { id = 157738, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [MAGE_ARCANE_DIFF] = {
        { 1, { id = 157913, level = "15" }, },
        { 2, { id = 108843, level = "15" }, },
        { 3, { id = 108839, level = "15" }, },
        { 5, { id = 108978, level = "30" }, },
        { 6, { id = 140468, level = "30" }, },
        { 7, { id = 11426, level = "30" }, },
        { 9, { id = 113724, level = "45" }, },
        { 10, { id = 111264, level = "45" }, },
        { 11, { id = 102051, level = "45" }, },
        { 13, { id = 110959, level = "60" }, },
        { 14, { id = 86949, level = "60" }, },
        { 15, { id = 11958, level = "60" }, },
        { 16, { id = 114923, level = "75" }, },
        { 17, { id = 157976, level = "75" }, },
        { 18, { id = 157980, level = "75" }, },
        { 20, { id = 55342, level = "90" }, },
        { 21, { id = 116011, level = "90" }, },
        { 22, { id = 1463, level = "90" }, },
        { 24, { id = 155147, level = "100" }, },
        { 25, { id = 152087, level = "100" }, },
        { 26, { id = 153626, level = "100" }, },
      },
      [MAGE_FIRE_DIFF] = {
        { 1, { id = 157913, level = "15" }, },
        { 2, { id = 108843, level = "15" }, },
        { 3, { id = 108839, level = "15" }, },
        { 5, { id = 108978, level = "30" }, },
        { 6, { id = 140468, level = "30" }, },
        { 7, { id = 11426, level = "30" }, },
        { 9, { id = 113724, level = "45" }, },
        { 10, { id = 111264, level = "45" }, },
        { 11, { id = 102051, level = "45" }, },
        { 13, { id = 110959, level = "60" }, },
        { 14, { id = 86949, level = "60" }, },
        { 15, { id = 11958, level = "60" }, },
        { 16, { id = 44457, level = "75" }, },
        { 17, { id = 157976, level = "75" }, },
        { 18, { id = 157981, level = "75" }, },
        { 20, { id = 55342, level = "90" }, },
        { 21, { id = 116011, level = "90" }, },
        { 22, { id = 1463, level = "90" }, },
        { 24, { id = 155148, level = "100" }, },
        { 25, { id = 152087, level = "100" }, },
        { 26, { id = 153561, level = "100" }, },
      },
      [MAGE_FROST_DIFF] = {
        { 1, { id = 157913, level = "15" }, },
        { 2, { id = 108843, level = "15" }, },
        { 3, { id = 108839, level = "15" }, },
        { 5, { id = 108978, level = "30" }, },
        { 6, { id = 140468, level = "30" }, },
        { 7, { id = 11426, level = "30" }, },
        { 9, { id = 113724, level = "45" }, },
        { 10, { id = 111264, level = "45" }, },
        { 11, { id = 102051, level = "45" }, },
        { 13, { id = 110959, level = "60" }, },
        { 14, { id = 86949, level = "60" }, },
        { 15, { id = 11958, level = "60" }, },
        { 16, { id = 112948, level = "75" }, },
        { 17, { id = 157976, level = "75" }, },
        { 18, { id = 157997, level = "75" }, },
        { 20, { id = 55342, level = "90" }, },
        { 21, { id = 116011, level = "90" }, },
        { 22, { id = 1463, level = "90" }, },
        { 24, { id = 155149, level = "100" }, },
        { 25, { id = 152087, level = "100" }, },
        { 26, { id = 153595, level = "100" }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majormage",
      [GLYPH_DIFF] = {
        { 1, 115718 },
        { 2, 62210 },
        { 3, 56365 },
        { 4, 56368 },
        { 5, 115705 },
        { 6, 115703 },
        { 7, 115710 },
        { 8, 159485 },
        { 9, 56376 },
        { 10, 61205 },
        { 11, 115723 },
        { 12, 56364 },
        { 13, 89926 },
        { 14, 56375 },
        { 15, 146659 },
        { 16, 159486 },
        { 17, 115700 },
        { 18, 86209 },
        { 19, 115713 },
        { 20, 56377 },
        { 21, 63090 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minormage",
      [GLYPH_DIFF] = {
        { 1, 57925 },
        { 2, 147353 },
        { 3, 126748 },
        { 4, 56382 },
        { 5, 146662 },
        { 6, 63092 },
        { 7, 56384 },
        { 8, 89749 },
        { 9, 146976 },
      },
    },
  },
}

data["CLASS_MONK"] = {
  name = "Monk",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("MONK"),
      [MONK_DIFF] = {
        { 1, 106904 },
        { 2, 106902},
        { 4, { id = 115074, level = "1" }, },
        { 5, { id = 100780, level = "1" }, },
        { 6, { id = 116812, level = "1" }, },
        { 7, { id = 103985, level = "1" }, },
        { 8, { id = 120277, level = "1" }, },
        { 9, { id = 100787, level = "3" }, },
        { 10, { id = 109132, level = "5" }, },
        { 11, { id = 100784, level = "7" }, },
        { 12, { id = 120272, level = "10" }, },
        { 13, { id = 116694, level = "12" }, },
        { 14, { id = 115546, level = "14" }, },
        { 15, { id = 115178, level = "18" }, },
        { 16, { id = 115450, level = "20" }, },
        { 17, { id = 126892, level = "20" }, },
        { 18, { id = 115080, level = "22" }, },
        { 19, { id = 115203, level = "24" }, },
        { 20, { id = 115072, level = "26" }, },
        { 21, { id = 137562, level = "30" }, },
        { 22, { id = 116705, level = "32" }, },
        { 23, { id = 115078, level = "44" }, },
        { 24, { id = 101546, level = "46" }, },
        { 25, { id = 117952, level = "54" }, },
        { 26, { id = 101643, level = "87" }, },
        { 27, { id = 119996, level = "87" }, },
      },
    },
    {
      name = "Brewmaster",
      CoinTexture = "texture:Interface\\Icons\\spell_monk_brewmaster_spec",
      [MONK_DIFF] = {
        { 1, { id = 157445, level = "1" }, },
        { 2, { id = 115074, level = "1" }, },
        { 3, { id = 100780, level = "1" }, },
        { 4, { id = 116812, level = "1" }, },
        { 5, { id = 103985, level = "1" }, },
        { 6, { id = 120277, level = "1" }, },
        { 7, { id = 100787, level = "3" }, },
        { 8, { id = 109132, level = "5" }, },
        { 9, { id = 100784, level = "7" }, },
        { 10, { id = 161608, level = "10" }, },
        { 11, { id = 115180, level = "10" }, },
        { 12, { id = 124146, level = "10" }, },
        { 13, { id = 158298, level = "10" }, },
        { 14, { id = 115069, level = "10" }, },
        { 15, { id = 120272, level = "10" }, },
        { 16, { id = 121253, level = "11" }, },
        { 17, { id = 116694, level = "12" }, },
        { 18, { id = 115546, level = "14" }, },
        { 19, { id = 115181, level = "18" }, },
        { 20, { id = 115178, level = "18" }, },
        { 21, { id = 115450, level = "20" }, },
        { 22, { id = 126892, level = "20" }, },
        { 23, { id = 115080, level = "22" }, },
        { 24, { id = 115203, level = "24" }, },
        { 25, { id = 115072, level = "26" }, },
        { 26, { id = 115295, level = "26" }, },
        { 27, { id = 137562, level = "30" }, },
        { 28, { id = 116705, level = "32" }, },
        { 29, { id = 117967, level = "34" }, },
        { 30, { id = 128938, level = "36" }, },
        { 101, { id = 115308, level = "36" }, },
        { 102, { id = 115078, level = "44" }, },
        { 103, { id = 126060, level = "45" }, },
        { 104, { id = 101546, level = "46" }, },
        { 105, { id = 120225, level = "50" }, },
        { 106, { id = 117952, level = "54" }, },
        { 107, { id = 124502, level = "56" }, },
        { 108, { id = 115315, level = "70" }, },
        { 109, { id = 119582, level = "75" }, },
        { 110, { id = 117906, level = "80", rank = MASTERY }, },
        { 111, { id = 116781, level = "81" }, },
        { 112, { id = 115176, level = "82" }, },
        { 113, { id = 101643, level = "87" }, },
        { 114, { id = 119996, level = "87" }, },
        { 115, { id = 165379, level = "90" }, },
        { 116, { id = 157361, level = "92+", rank = DRAENORPERK }, },
        { 117, { id = 157366, level = "92+", rank = DRAENORPERK }, },
        { 118, { id = 157362, level = "92+", rank = DRAENORPERK }, },
        { 119, { id = 157363, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Mistweaver",
      CoinTexture = "texture:Interface\\Icons\\spell_monk_mistweaver_spec",
      [MONK_DIFF] = {
        { 1, { id = 115074, level = "1" }, },
        { 2, { id = 100780, level = "1" }, },
        { 3, { id = 116812, level = "1" }, },
        { 4, { id = 103985, level = "1" }, },
        { 5, { id = 120277, level = "1" }, },
        { 6, { id = 100787, level = "3" }, },
        { 7, { id = 109132, level = "5" }, },
        { 8, { id = 100784, level = "7" }, },
        { 9, { id = 139598, level = "10" }, },
        { 10, { id = 121278, level = "10" }, },
        { 11, { id = 115175, level = "10" }, },
        { 12, { id = 154436, level = "10" }, },
        { 13, { id = 115070, level = "10" }, },
        { 14, { id = 116645, level = "10" }, },
        { 15, { id = 120272, level = "10" }, },
        { 16, { id = 116694, level = "12" }, },
        { 17, { id = 115546, level = "14" }, },
        { 18, { id = 124682, level = "16" }, },
        { 19, { id = 115178, level = "18" }, },
        { 20, { id = 115450, level = "20" }, },
        { 21, { id = 115451, level = "20" }, },
        { 22, { id = 126892, level = "20" }, },
        { 23, { id = 115921, level = "22" }, },
        { 24, { id = 115080, level = "22" }, },
        { 25, { id = 115203, level = "24" }, },
        { 26, { id = 115151, level = "24" }, },
        { 27, { id = 115072, level = "26" }, },
        { 28, { id = 137562, level = "30" }, },
        { 29, { id = 116705, level = "32" }, },
        { 30, { id = 115078, level = "44" }, },
        { 101, { id = 154555, level = "45" }, },
        { 102, { id = 101546, level = "46" }, },
        { 103, { id = 120224, level = "50" }, },
        { 104, { id = 116849, level = "50" }, },
        { 105, { id = 117952, level = "54" }, },
        { 106, { id = 123766, level = "56" }, },
        { 107, { id = 115294, level = "56" }, },
        { 108, { id = 107428, level = "56" }, },
        { 109, { id = 116670, level = "62" }, },
        { 110, { id = 115460, level = "64" }, },
        { 111, { id = 116680, level = "66" }, },
        { 112, { id = 115313, level = "70" }, },
        { 113, { id = 115310, level = "78" }, },
        { 114, { id = 117907, level = "80", rank = MASTERY }, },
        { 115, { id = 101643, level = "87" }, },
        { 116, { id = 119996, level = "87" }, },
        { 117, { id = 165397, level = "90" }, },
        { 118, { id = 157361, level = "92+", rank = DRAENORPERK }, },
        { 119, { id = 157366, level = "92+", rank = DRAENORPERK }, },
        { 120, { id = 157401, level = "92+", rank = DRAENORPERK }, },
        { 121, { id = 157398, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Windwalker",
      CoinTexture = "texture:Interface\\Icons\\spell_monk_windwalker_spec",
      [MONK_DIFF] = {
        { 1, { id = 157445, level = "1" }, },
        { 2, { id = 115074, level = "1" }, },
        { 3, { id = 100780, level = "1" }, },
        { 4, { id = 116812, level = "1" }, },
        { 5, { id = 103985, level = "1" }, },
        { 6, { id = 120277, level = "1" }, },
        { 7, { id = 100787, level = "3" }, },
        { 8, { id = 109132, level = "5" }, },
        { 9, { id = 100784, level = "7" }, },
        { 10, { id = 137384, level = "10" }, },
        { 11, { id = 124146, level = "10" }, },
        { 12, { id = 113656, level = "10" }, },
        { 13, { id = 120272, level = "10" }, },
        { 14, { id = 116694, level = "12" }, },
        { 15, { id = 115546, level = "14" }, },
        { 16, { id = 101545, level = "18" }, },
        { 17, { id = 115178, level = "18" }, },
        { 18, { id = 128595, level = "20" }, },
        { 19, { id = 115450, level = "20" }, },
        { 20, { id = 126892, level = "20" }, },
        { 21, { id = 115080, level = "22" }, },
        { 22, { id = 122470, level = "22" }, },
        { 23, { id = 115203, level = "24" }, },
        { 24, { id = 116092, level = "26" }, },
        { 25, { id = 115072, level = "26" }, },
        { 26, { id = 116095, level = "28" }, },
        { 27, { id = 137562, level = "30" }, },
        { 28, { id = 116705, level = "32" }, },
        { 29, { id = 115288, level = "36" }, },
        { 30, { id = 115078, level = "44" }, },
        { 101, { id = 101546, level = "46" }, },
        { 102, { id = 120227, level = "50" }, },
        { 103, { id = 117952, level = "54" }, },
        { 104, { id = 123980, level = "56" }, },
        { 105, { id = 107428, level = "56" }, },
        { 106, { id = 116740, level = "56" }, },
        { 107, { id = 137639, level = "75" }, },
        { 108, { id = 115636, level = "80", rank = MASTERY }, },
        { 109, { id = 166916, level = "80" }, },
        { 110, { id = 116781, level = "81" }, },
        { 111, { id = 115176, level = "82" }, },
        { 112, { id = 101643, level = "87" }, },
        { 113, { id = 119996, level = "87" }, },
        { 114, { id = 165398, level = "90" }, },
        { 115, { id = 157411, level = "92+", rank = DRAENORPERK }, },
        { 116, { id = 157415, level = "92+", rank = DRAENORPERK }, },
        { 117, { id = 157361, level = "92+", rank = DRAENORPERK }, },
        { 118, { id = 157366, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [MONK_BM_DIFF] = {
        { 1, { id = 115173, level = "15" }, },
        { 2, { id = 116841, level = "15" }, },
        { 3, { id = 115174, level = "15" }, },
        { 5, { id = 115098, level = "30" }, },
        { 6, { id = 124081, level = "30" }, },
        { 7, { id = 123986, level = "30" }, },
        { 9, { id = 121817, level = "45" }, },
        { 10, { id = 115396, level = "45" }, },
        { 11, { id = 115399, level = "45" }, },
        { 13, { id = 116844, level = "60" }, },
        { 14, { id = 119392, level = "60" }, },
        { 15, { id = 119381, level = "60" }, },
        { 16, { id = 122280, level = "75" }, },
        { 17, { id = 122278, level = "75" }, },
        { 18, { id = 122783, level = "75" }, },
        { 20, { id = 116847, level = "90" }, },
        { 21, { id = 123904, level = "90" }, },
        { 22, { id = 115008, level = "90" }, },
        { 24, { id = 157533, level = "100" }, },
        { 25, { id = 157676, level = "100" }, },
        { 26, { id = 152173, level = "100" }, },
      },
      [MONK_MW_DIFF] = {
        { 1, { id = 115173, level = "15" }, },
        { 2, { id = 116841, level = "15" }, },
        { 3, { id = 115174, level = "15" }, },
        { 5, { id = 115098, level = "30" }, },
        { 6, { id = 124081, level = "30" }, },
        { 7, { id = 123986, level = "30" }, },
        { 9, { id = 121817, level = "45" }, },
        { 10, { id = 115396, level = "45" }, },
        { 11, { id = 115399, level = "45" }, },
        { 13, { id = 116844, level = "60" }, },
        { 14, { id = 119392, level = "60" }, },
        { 15, { id = 119381, level = "60" }, },
        { 16, { id = 122280, level = "75" }, },
        { 17, { id = 122278, level = "75" }, },
        { 18, { id = 122783, level = "75" }, },
        { 20, { id = 116847, level = "90" }, },
        { 21, { id = 123904, level = "90" }, },
        { 22, { id = 115008, level = "90" }, },
        { 24, { id = 157535, level = "100" }, },
        { 25, { id = 157675, level = "100" }, },
        { 26, { id = 173841, level = "100" }, },
      },
      [MONK_WW_DIFF] = {
        { 1, { id = 115173, level = "15" }, },
        { 2, { id = 116841, level = "15" }, },
        { 3, { id = 115174, level = "15" }, },
        { 5, { id = 115098, level = "30" }, },
        { 6, { id = 124081, level = "30" }, },
        { 7, { id = 123986, level = "30" }, },
        { 9, { id = 121817, level = "45" }, },
        { 10, { id = 115396, level = "45" }, },
        { 11, { id = 115399, level = "45" }, },
        { 13, { id = 116844, level = "60" }, },
        { 14, { id = 119392, level = "60" }, },
        { 15, { id = 119381, level = "60" }, },
        { 16, { id = 122280, level = "75" }, },
        { 17, { id = 122278, level = "75" }, },
        { 18, { id = 122783, level = "75" }, },
        { 20, { id = 116847, level = "90" }, },
        { 21, { id = 123904, level = "90" }, },
        { 22, { id = 115008, level = "90" }, },
        { 24, { id = 152175, level = "100" }, },
        { 25, { id = 152174, level = "100" }, },
        { 26, { id = 152173, level = "100" }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majormonk",
      [GLYPH_DIFF] = {
        { 1, 123394 },
        { 2, 146954 },
        { 3, 171926 },
        { 4, 159487 },
        { 5, 125671 },
        { 6, 173182 },
        { 7, 124997 },
        { 8, 146953 },
        { 9, 159534 },
        { 10, 123401 },
        { 11, 159495 },
        { 12, 125967 },
        { 13, 124989 },
        { 14, 123763 },
        { 15, 146952 },
        { 16, 125755 },
        { 17, 146951 },
        { 18, 159496 },
        { 19, 123334 },
        { 20, 159536 },
        { 21, 120483 },
        { 22, 146950 },
        { 23, 159490 },
        { 24, 159492 },
        { 25, 123391 },
        { 26, 125678 },
        { 27, 123023 },
        { 28, 159497 },
        { 29, 159545 },
        { 30, 120477 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minormonk",
      [GLYPH_DIFF] = {
        { 1, 125931 },
        { 2, 125872 },
        { 3, 123403 },
        { 4, 125732 },
        { 5, 125660 },
        { 6, 125151 },
        { 7, 125154 },
        { 8, 125901 },
        { 9, 125893 },
      },
    },
  },
}

data["CLASS_PALADIN"] = {
  name = "Paladin",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("PALADIN"),
      [PALADIN_DIFF] = {
        { 1, 76271 },
        { 2, 76294 },
        { 4, { id = 107, level = "1" }, },
        { 5, { id = 35395, level = "1" }, },
        { 6, { id = 82242, level = "1" }, },
        { 7, { id = 105361, level = "3" }, },
        { 8, { id = 20271, level = "5" }, },
        { 9, { id = 853, level = "7" }, },
        { 10, { id = 85673, level = "9" }, },
        { 11, { id = 25780, level = "12" }, },
        { 12, { id = 7328, level = "13" }, },
        { 13, { id = 62124, level = "15" }, },
        { 14, { id = 633, level = "16" }, },
        { 15, { id = 642, level = "18" }, },
        { 16, { id = 4987, level = "20" }, },
        { 17, { id = 13819, level = "20", rank = COLOR_ALLIANCE.."Human" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 18, { id = 73629, level = "20", rank = COLOR_ALLIANCE.."|cFF4444BBDraenei" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 19, { id = 69820, level = "20", rank = COLOR_HORDE.."Tauren" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 20, { id = 34769, level = "20", rank = COLOR_HORDE.."Blood Elf" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 21, { id = 498, level = "26" }, },
        { 22, { id = 20217, level = "30" }, },
        { 23, { id = 20165, level = "32" }, },
        { 24, { id = 96231, level = "36" }, },
        { 25, { id = 24275, level = "38" }, },
        { 26, { id = 23214, level = "40", rank = COLOR_ALLIANCE.."Human" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 27, { id = 73630, level = "40", rank = COLOR_ALLIANCE.."Draenei" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 28, { id = 69826, level = "40", rank = COLOR_HORDE.."Tauren" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 29, { id = 34767, level = "40", rank = COLOR_HORDE.."Blood Elf" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 30, { id = 32223, level = "44" }, },
        { 101, { id = 10326, level = "46" }, },
        { 102, { id = 1022, level = "48" }, },
        { 103, { id = 1044, level = "52" }, },
        { 104, { id = 25956, level = "58" }, },
        { 105, { id = 6940, level = "80" }, },
        { 106, { id = 19740, level = "81" }, },
        { 107, { id = 115675, level = "85" }, },
      },
    },
    {
      name = "Holy",
      CoinTexture = "texture:Interface\\Icons\\spell_holy_holybolt",
      [PALADIN_DIFF] = {
        { 1, { id = 107, level = "1" }, },
        { 2, { id = 35395, level = "1" }, },
        { 3, { id = 82242, level = "1" }, },
        { 4, { id = 105361, level = "3" }, },
        { 5, { id = 20271, level = "5" }, },
        { 6, { id = 853, level = "7" }, },
        { 7, { id = 85673, level = "9" }, },
        { 8, { id = 112859, level = "10" }, },
        { 9, { id = 20473, level = "10" }, },
        { 10, { id = 25780, level = "12" }, },
        { 11, { id = 7328, level = "13" }, },
        { 12, { id = 19750, level = "14" }, },
        { 13, { id = 62124, level = "15" }, },
        { 14, { id = 633, level = "16" }, },
        { 15, { id = 642, level = "18" }, },
        { 16, { id = 4987, level = "20" }, },
        { 17, { id = 2812, level = "20" }, },
        { 18, { id = 53551, level = "20" }, },
        { 19, { id = 498, level = "26" }, },
        { 20, { id = 82327, level = "28" }, },
        { 21, { id = 20217, level = "30" }, },
        { 22, { id = 20165, level = "32" }, },
        { 23, { id = 31868, level = "34" }, },
        { 24, { id = 96231, level = "36" }, },
        { 25, { id = 24275, level = "38" }, },
        { 26, { id = 53563, level = "39" }, },
        { 27, { id = 32223, level = "44" }, },
        { 28, { id = 10326, level = "46" }, },
        { 29, { id = 1022, level = "48" }, },
        { 30, { id = 53576, level = "50" }, },
        { 101, { id = 1044, level = "52" }, },
        { 102, { id = 82326, level = "54" }, },
        { 103, { id = 88821, level = "56" }, },
        { 104, { id = 25956, level = "58" }, },
        { 105, { id = 31821, level = "60" }, },
        { 106, { id = 85222, level = "70" }, },
        { 107, { id = 31842, level = "72" }, },
        { 108, { id = 6940, level = "80" }, },
        { 109, { id = 76669, level = "80", rank = MASTERY }, },
        { 110, { id = 19740, level = "81" }, },
        { 111, { id = 115675, level = "85" }, },
        { 112, { id = 165380, level = "90" }, },
        { 113, { id = 157453, level = "92+", rank = DRAENORPERK }, },
        { 114, { id = 157478, level = "92+", rank = DRAENORPERK }, },
        { 115, { id = 157455, level = "92+", rank = DRAENORPERK }, },
        { 116, { id = 157482, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Protection",
      CoinTexture = "texture:Interface\\Icons\\ability_paladin_shieldofthetemplar",
      [PALADIN_DIFF] = {
        { 1, { id = 107, level = "1" }, },
        { 2, { id = 35395, level = "1" }, },
        { 3, { id = 82242, level = "1" }, },
        { 4, { id = 105361, level = "3" }, },
        { 5, { id = 20271, level = "5" }, },
        { 6, { id = 853, level = "7" }, },
        { 7, { id = 85673, level = "9" }, },
        { 8, { id = 31935, level = "10" }, },
        { 9, { id = 161608, level = "10" }, },
        { 10, { id = 53592, level = "10" }, },
        { 11, { id = 158298, level = "10" }, },
        { 12, { id = 105805, level = "10" }, },
        { 13, { id = 25780, level = "12" }, },
        { 14, { id = 7328, level = "13" }, },
        { 15, { id = 19750, level = "14" }, },
        { 16, { id = 62124, level = "15" }, },
        { 17, { id = 633, level = "16" }, },
        { 18, { id = 642, level = "18" }, },
        { 19, { id = 4987, level = "20" }, },
        { 20, { id = 53595, level = "20" }, },
        { 21, { id = 119072, level = "20" }, },
        { 22, { id = 31801, level = "24" }, },
        { 23, { id = 498, level = "26" }, },
        { 24, { id = 105424, level = "28" }, },
        { 25, { id = 20217, level = "30" }, },
        { 26, { id = 20165, level = "32" }, },
        { 27, { id = 26573, level = "34" }, },
        { 28, { id = 96231, level = "36" }, },
        { 29, { id = 24275, level = "38" }, },
        { 30, { id = 53600, level = "40" }, },
        { 101, { id = 20154, level = "42" }, },
        { 102, { id = 32223, level = "44" }, },
        { 103, { id = 10326, level = "46" }, },
        { 104, { id = 1022, level = "48" }, },
        { 105, { id = 85043, level = "50" }, },
        { 106, { id = 159374, level = "50" }, },
        { 107, { id = 1044, level = "52" }, },
        { 108, { id = 25956, level = "58" }, },
        { 109, { id = 1038, level = "66" }, },
        { 110, { id = 31850, level = "70" }, },
        { 111, { id = 86659, level = "75" }, },
        { 112, { id = 161800, level = "76" }, },
        { 113, { id = 6940, level = "80" }, },
        { 114, { id = 76671, level = "80", rank = MASTERY }, },
        { 115, { id = 19740, level = "81" }, },
        { 116, { id = 115675, level = "85" }, },
        { 117, { id = 165375, level = "90" }, },
        { 118, { id = 157485, level = "92+", rank = DRAENORPERK }, },
        { 119, { id = 157488, level = "92+", rank = DRAENORPERK }, },
        { 120, { id = 157486, level = "92+", rank = DRAENORPERK }, },
        { 121, { id = 157482, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Retribution",
      CoinTexture = "texture:Interface\\Icons\\spell_holy_auraoflight",
      [PALADIN_DIFF] = {
        { 1, { id = 107, level = "1" }, },
        { 2, { id = 35395, level = "1" }, },
        { 3, { id = 82242, level = "1" }, },
        { 4, { id = 105361, level = "3" }, },
        { 5, { id = 20271, level = "5" }, },
        { 6, { id = 853, level = "7" }, },
        { 7, { id = 85673, level = "9" }, },
        { 8, { id = 53503, level = "10" }, },
        { 9, { id = 85256, level = "10" }, },
        { 10, { id = 25780, level = "12" }, },
        { 11, { id = 7328, level = "13" }, },
        { 12, { id = 19750, level = "14" }, },
        { 13, { id = 62124, level = "15" }, },
        { 14, { id = 633, level = "16" }, },
        { 15, { id = 642, level = "18" }, },
        { 16, { id = 4987, level = "20" }, },
        { 17, { id = 53595, level = "20" }, },
        { 18, { id = 31801, level = "24" }, },
        { 19, { id = 498, level = "26" }, },
        { 20, { id = 20217, level = "30" }, },
        { 21, { id = 20165, level = "32" }, },
        { 22, { id = 53385, level = "34" }, },
        { 23, { id = 31868, level = "34" }, },
        { 24, { id = 96231, level = "36" }, },
        { 25, { id = 24275, level = "38" }, },
        { 26, { id = 20154, level = "42" }, },
        { 27, { id = 32223, level = "44" }, },
        { 28, { id = 879, level = "46" }, },
        { 29, { id = 10326, level = "46" }, },
        { 30, { id = 1022, level = "48" }, },
        { 101, { id = 1044, level = "52" }, },
        { 102, { id = 121783, level = "54" }, },
        { 103, { id = 25956, level = "58" }, },
        { 104, { id = 20164, level = "70" }, },
        { 105, { id = 31884, level = "72" }, },
        { 106, { id = 140333, level = "80" }, },
        { 107, { id = 6940, level = "80" }, },
        { 108, { id = 76672, level = "80", rank = MASTERY }, },
        { 109, { id = 167187, level = "80" }, },
        { 110, { id = 19740, level = "81" }, },
        { 111, { id = 115675, level = "85" }, },
        { 112, { id = 165381, level = "90" }, },
        { 113, { id = 174718, level = "92+", rank = DRAENORPERK }, },
        { 114, { id = 157496, level = "92+", rank = DRAENORPERK }, },
        { 115, { id = 157493, level = "92+", rank = DRAENORPERK }, },
        { 116, { id = 157482, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [PALADIN_HOLY_DIFF] = {
        { 1, { id = 85499, level = "15" }, },
        { 2, { id = 87172, level = "15" }, },
        { 3, { id = 26023, level = "15" }, },
        { 5, { id = 105593, level = "30" }, },
        { 6, { id = 20066, level = "30" }, },
        { 7, { id = 115750, level = "30" }, },
        { 9, { id = 85804, level = "45" }, },
        { 10, { id = 114163, level = "45" }, },
        { 11, { id = 148039, level = "45" }, },
        { 13, { id = 114039, level = "60" }, },
        { 14, { id = 114154, level = "60" }, },
        { 15, { id = 105622, level = "60" }, },
        { 16, { id = 105809, level = "75" }, },
        { 17, { id = 53376, level = "75" }, },
        { 18, { id = 86172, level = "75" }, },
        { 20, { id = 114165, level = "90" }, },
        { 21, { id = 114158, level = "90" }, },
        { 22, { id = 114157, level = "90" }, },
        { 24, { id = 156910, level = "100" }, },
        { 25, { id = 157007, level = "100" }, },
        { 26, { id = 157047, level = "100" }, },
      },
      [PALADIN_PROT_DIFF] = {
        { 1, { id = 85499, level = "15" }, },
        { 2, { id = 87172, level = "15" }, },
        { 3, { id = 26023, level = "15" }, },
        { 5, { id = 105593, level = "30" }, },
        { 6, { id = 20066, level = "30" }, },
        { 7, { id = 115750, level = "30" }, },
        { 9, { id = 85804, level = "45" }, },
        { 10, { id = 114163, level = "45" }, },
        { 11, { id = 20925, level = "45" }, },
        { 13, { id = 114039, level = "60" }, },
        { 14, { id = 114154, level = "60" }, },
        { 15, { id = 105622, level = "60" }, },
        { 16, { id = 105809, level = "75" }, },
        { 17, { id = 171648, level = "75" }, },
        { 18, { id = 86172, level = "75" }, },
        { 20, { id = 114165, level = "90" }, },
        { 21, { id = 114158, level = "90" }, },
        { 22, { id = 114157, level = "90" }, },
        { 24, { id = 152263, level = "100" }, },
        { 25, { id = 152262, level = "100" }, },
        { 26, { id = 152261, level = "100" }, },
      },
      [PALADIN_RET_DIFF] = {
        { 1, { id = 85499, level = "15" }, },
        { 2, { id = 87172, level = "15" }, },
        { 3, { id = 26023, level = "15" }, },
        { 5, { id = 105593, level = "30" }, },
        { 6, { id = 20066, level = "30" }, },
        { 7, { id = 115750, level = "30" }, },
        { 9, { id = 85804, level = "45" }, },
        { 10, { id = 114163, level = "45" }, },
        { 11, { id = 20925, level = "45" }, },
        { 13, { id = 114039, level = "60" }, },
        { 14, { id = 114154, level = "60" }, },
        { 15, { id = 105622, level = "60" }, },
        { 16, { id = 105809, level = "75" }, },
        { 17, { id = 53376, level = "75" }, },
        { 18, { id = 86172, level = "75" }, },
        { 20, { id = 114165, level = "90" }, },
        { 21, { id = 114158, level = "90" }, },
        { 22, { id = 114157, level = "90" }, },
        { 24, { id = 152263, level = "100" }, },
        { 25, { id = 152262, level = "100" }, },
        { 26, { id = 157048, level = "100" }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majorpaladin",
      [GLYPH_DIFF] = {
        { 1, 159548 },
        { 2, 54927 },
        { 3, 63218 },
        { 4, 54943 },
        { 5, 54931 },
        { 6, 171929 },
        { 7, 54928 },
        { 8, 56414 },
        { 9, 56420 },
        { 10, 146955 },
        { 11, 54924 },
        { 12, 146956 },
        { 13, 63220 },
        { 14, 159572 },
        { 15, 54939 },
        { 16, 54922 },
        { 17, 54935 },
        { 18, 57955 },
        { 19, 54930 },
        { 20, 63219 },
        { 21, 159579 },
        { 22, 146957 },
        { 23, 54938 },
        { 24, 63224 },
        { 25, 54923 },
        { 26, 54937 },
        { 27, 56416 },
        { 28, 159592 },
        { 29, 54940 },
        { 30, 122028 },
        { 101, 162604 },
        { 102, 93466 },
        { 103, 54926 },
        { 104, 63222 },
        { 105, 119477 },
        { 106, 159557 },
        { 107, 159573 },
        { 108, 54936 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minorpaladin",
      [GLYPH_DIFF] = {
        { 1, 115934 },
        { 2, 125043 },
        { 3, 57954 },
        { 4, 115738 },
        { 5, 146959 },
        { 6, 115933 },
        { 7, 57947 },
        { 8, 146958 },
        { 9, 115931 },
        { 10, 89401 },
        { 11, 57958 },
        { 12, 57979 },
      },
    },
  },
}

data["CLASS_PRIEST"] = {
  name = "Priest",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("PRIEST"),
      [PRIEST_DIFF] = {
        { 1, 76279 },
        { 2, 76301 },
        { 4, { id = 5019, level = "1" }, },
        { 5, { id = 585, level = "1" }, },
        { 6, { id = 589, level = "3" }, },
        { 7, { id = 17, level = "5" }, },
        { 8, { id = 2061, level = "7" }, },
        { 9, { id = 2006, level = "18" }, },
        { 10, { id = 21562, level = "22" }, },
        { 11, { id = 586, level = "24" }, },
        { 12, { id = 528, level = "26" }, },
        { 13, { id = 48045, level = "28" }, },
        { 14, { id = 9484, level = "32" }, },
        { 15, { id = 1706, level = "34" }, },
        { 16, { id = 2096, level = "42" }, },
        { 17, { id = 34433, level = "42" }, },
        { 18, { id = 6346, level = "54" }, },
        { 19, { id = 33076, level = "68" }, },
        { 20, { id = 32375, level = "72" }, },
        { 21, { id = 73325, level = "84" }, },
      },
    },
    {
      name = "Discipline",
      CoinTexture = "texture:Interface\\Icons\\spell_holy_powerwordshield",
      [PRIEST_DIFF] = {
        { 1, { id = 5019, level = "1" }, },
        { 2, { id = 585, level = "1" }, },
        { 3, { id = 589, level = "3" }, },
        { 4, { id = 17, level = "5" }, },
        { 5, { id = 2061, level = "7" }, },
        { 6, { id = 52798, level = "10" }, },
        { 7, { id = 95860, level = "10" }, },
        { 8, { id = 47540, level = "10" }, },
        { 9, { id = 47536, level = "10" }, },
        { 10, { id = 87336, level = "10" }, },
        { 11, { id = 14914, level = "18" }, },
        { 12, { id = 2006, level = "18" }, },
        { 13, { id = 132157, level = "20" }, },
        { 14, { id = 21562, level = "22" }, },
        { 15, { id = 527, level = "22" }, },
        { 16, { id = 47515, level = "24" }, },
        { 17, { id = 586, level = "24" }, },
        { 18, { id = 528, level = "26" }, },
        { 19, { id = 48045, level = "28" }, },
        { 20, { id = 45243, level = "30" }, },
        { 21, { id = 9484, level = "32" }, },
        { 22, { id = 2060, level = "34" }, },
        { 23, { id = 1706, level = "34" }, },
        { 24, { id = 81749, level = "38" }, },
        { 25, { id = 2096, level = "42" }, },
        { 26, { id = 34433, level = "42" }, },
        { 27, { id = 81662, level = "44" }, },
        { 28, { id = 47517, level = "45" }, },
        { 29, { id = 596, level = "46" }, },
        { 30, { id = 81700, level = "50" }, },
        { 101, { id = 15487, level = "52" }, },
        { 102, { id = 6346, level = "54" }, },
        { 103, { id = 33206, level = "58" }, },
        { 104, { id = 33076, level = "68" }, },
        { 105, { id = 62618, level = "70" }, },
        { 106, { id = 32375, level = "72" }, },
        { 107, { id = 77484, level = "80", rank = MASTERY }, },
        { 108, { id = 73325, level = "84" }, },
        { 109, { id = 165376, level = "90" }, },
        { 110, { id = 157197, level = "92+", rank = DRAENORPERK }, },
        { 111, { id = 157193, level = "92+", rank = DRAENORPERK }, },
        { 112, { id = 157145, level = "92+", rank = DRAENORPERK }, },
        { 113, { id = 157129, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Holy",
      CoinTexture = "texture:Interface\\Icons\\spell_holy_guardianspirit",
      [PRIEST_DIFF] = {
        { 1, { id = 5019, level = "1" }, },
        { 2, { id = 585, level = "1" }, },
        { 3, { id = 589, level = "3" }, },
        { 4, { id = 17, level = "5" }, },
        { 5, { id = 2061, level = "7" }, },
        { 6, { id = 88625, level = "10" }, },
        { 7, { id = 95861, level = "10" }, },
        { 8, { id = 87336, level = "10" }, },
        { 9, { id = 14914, level = "18" }, },
        { 10, { id = 2006, level = "18" }, },
        { 11, { id = 21562, level = "22" }, },
        { 12, { id = 527, level = "22" }, },
        { 13, { id = 586, level = "24" }, },
        { 14, { id = 528, level = "26" }, },
        { 15, { id = 139, level = "26" }, },
        { 16, { id = 48045, level = "28" }, },
        { 17, { id = 45243, level = "30" }, },
        { 18, { id = 20711, level = "30" }, },
        { 19, { id = 9484, level = "32" }, },
        { 20, { id = 2060, level = "34" }, },
        { 21, { id = 1706, level = "34" }, },
        { 22, { id = 63733, level = "34" }, },
        { 23, { id = 126135, level = "36" }, },
        { 24, { id = 2096, level = "42" }, },
        { 25, { id = 34433, level = "42" }, },
        { 26, { id = 596, level = "46" }, },
        { 27, { id = 32546, level = "48" }, },
        { 28, { id = 34861, level = "50" }, },
        { 29, { id = 6346, level = "54" }, },
        { 30, { id = 81209, level = "56" }, },
        { 101, { id = 81206, level = "56" }, },
        { 102, { id = 81208, level = "56" }, },
        { 103, { id = 95649, level = "64" }, },
        { 104, { id = 33076, level = "68" }, },
        { 105, { id = 47788, level = "70" }, },
        { 106, { id = 32375, level = "72" }, },
        { 107, { id = 64843, level = "78" }, },
        { 108, { id = 77485, level = "80", rank = MASTERY }, },
        { 109, { id = 73325, level = "84" }, },
        { 110, { id = 165362, level = "90" }, },
        { 111, { id = 157206, level = "92+", rank = DRAENORPERK }, },
        { 112, { id = 157193, level = "92+", rank = DRAENORPERK }, },
        { 113, { id = 157145, level = "92+", rank = DRAENORPERK }, },
        { 114, { id = 157207, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Shadow",
      CoinTexture = "texture:Interface\\Icons\\spell_shadow_shadowwordpain",
      [PRIEST_DIFF] = {
        { 1, { id = 5019, level = "1" }, },
        { 2, { id = 585, level = "1" }, },
        { 3, { id = 589, level = "3" }, },
        { 4, { id = 17, level = "5" }, },
        { 5, { id = 2061, level = "7" }, },
        { 6, { id = 165201, level = "10" }, },
        { 7, { id = 15407, level = "10" }, },
        { 8, { id = 2006, level = "18" }, },
        { 9, { id = 2944, level = "21" }, },
        { 10, { id = 8092, level = "21" }, },
        { 11, { id = 95740, level = "21" }, },
        { 12, { id = 21562, level = "22" }, },
        { 13, { id = 586, level = "24" }, },
        { 14, { id = 15473, level = "24" }, },
        { 15, { id = 528, level = "26" }, },
        { 16, { id = 48045, level = "28" }, },
        { 17, { id = 34914, level = "28" }, },
        { 18, { id = 9484, level = "32" }, },
        { 19, { id = 1706, level = "34" }, },
        { 20, { id = 2096, level = "42" }, },
        { 21, { id = 34433, level = "42" }, },
        { 22, { id = 78203, level = "42" }, },
        { 23, { id = 73510, level = "44" }, },
        { 24, { id = 32379, level = "46" }, },
        { 25, { id = 15487, level = "52" }, },
        { 26, { id = 6346, level = "54" }, },
        { 27, { id = 47585, level = "60" }, },
        { 28, { id = 33076, level = "68" }, },
        { 29, { id = 32375, level = "72" }, },
        { 30, { id = 64044, level = "74" }, },
        { 101, { id = 15286, level = "78" }, },
        { 102, { id = 77486, level = "80", rank = MASTERY }, },
        { 103, { id = 73325, level = "84" }, },
        { 104, { id = 165370, level = "90" }, },
        { 105, { id = 157223, level = "92+", rank = DRAENORPERK }, },
        { 106, { id = 157129, level = "92+", rank = DRAENORPERK }, },
        { 107, { id = 157217, level = "92+", rank = DRAENORPERK }, },
        { 108, { id = 157218, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [PRIEST_DISC_DIFF] = {
        { 1, { id = 19236, level = "15" }, },
        { 2, { id = 112833, level = "15" }, },
        { 3, { id = 108945, level = "15" }, },
        { 5, { id = 64129, level = "30" }, },
        { 6, { id = 121536, level = "30" }, },
        { 7, { id = 108942, level = "30" }, },
        { 9, { id = 109186, level = "45" }, },
        { 10, { id = 123040, level = "45" }, },
        { 11, { id = 129250, level = "45" }, },
        { 13, { id = 108920, level = "60" }, },
        { 14, { id = 8122, level = "60" }, },
        { 15, { id = 605, level = "60" }, },
        { 16, { id = 109142, level = "75" }, },
        { 17, { id = 10060, level = "75" }, },
        { 18, { id = 109964, level = "75" }, },
        { 20, { id = 121135, level = "90" }, },
        { 21, { id = 110744, level = "90" }, },
        { 22, { id = 120517, level = "90" }, },
        { 24, { id = 152118, level = "100" }, },
        { 25, { id = 152117, level = "100" }, },
        { 26, { id = 152116, level = "100" }, },
      },
      [PRIEST_HOLY_DIFF] = {
        { 1, { id = 19236, level = "15" }, },
        { 2, { id = 112833, level = "15" }, },
        { 3, { id = 108945, level = "15" }, },
        { 5, { id = 64129, level = "30" }, },
        { 6, { id = 121536, level = "30" }, },
        { 7, { id = 108942, level = "30" }, },
        { 9, { id = 109186, level = "45" }, },
        { 10, { id = 123040, level = "45" }, },
        { 11, { id = 129250, level = "45" }, },
        { 13, { id = 108920, level = "60" }, },
        { 14, { id = 8122, level = "60" }, },
        { 15, { id = 605, level = "60" }, },
        { 16, { id = 109142, level = "75" }, },
        { 17, { id = 10060, level = "75" }, },
        { 18, { id = 109175, level = "75" }, },
        { 20, { id = 121135, level = "90" }, },
        { 21, { id = 110744, level = "90" }, },
        { 22, { id = 120517, level = "90" }, },
        { 24, { id = 155245, level = "100" }, },
        { 25, { id = 152117, level = "100" }, },
        { 26, { id = 152116, level = "100" }, },
      },
      [PRIEST_SHADOW_DIFF] = {
        { 1, { id = 19236, level = "15" }, },
        { 2, { id = 112833, level = "15" }, },
        { 3, { id = 108945, level = "15" }, },
        { 5, { id = 64129, level = "30" }, },
        { 6, { id = 121536, level = "30" }, },
        { 7, { id = 108942, level = "30" }, },
        { 9, { id = 162448, level = "45" }, },
        { 10, { id = 123040, level = "45" }, },
        { 11, { id = 139139, level = "45" }, },
        { 13, { id = 108920, level = "60" }, },
        { 14, { id = 8122, level = "60" }, },
        { 15, { id = 605, level = "60" }, },
        { 16, { id = 109142, level = "75" }, },
        { 17, { id = 10060, level = "75" }, },
        { 18, { id = 162452, level = "75" }, },
        { 20, { id = 127632, level = "90" }, },
        { 21, { id = 122121, level = "90" }, },
        { 22, { id = 120644, level = "90" }, },
        { 24, { id = 155246, level = "100" }, },
        { 25, { id = 155361, level = "100" }, },
        { 26, { id = 155271, level = "100" }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majorpriest",
      [GLYPH_DIFF] = {
        { 1, 63248 },
        { 2, 55675 },
        { 3, 55673 },
        { 4, 159598 },
        { 5, 119864 },
        { 6, 63229 },
        { 7, 55684 },
        { 8, 55678 },
        { 9, 147778 },
        { 10, 159596 },
        { 11, 159599 },
        { 12, 119853 },
        { 13, 125045 },
        { 14, 55686 },
        { 15, 14771 },
        { 16, 119850 },
        { 17, 108939 },
        { 18, 126133 },
        { 19, 55691 },
        { 20, 87195 },
        { 21, 120585 },
        { 22, 162532 },
        { 23, 33371 },
        { 24, 159608 },
        { 25, 119866 },
        { 26, 55672 },
        { 27, 55685 },
        { 28, 55688 },
        { 29, 55676 },
        { 30, 171921 },
        { 101, 55677 },
        { 102, 33202 },
        { 103, 119872 },
        { 104, 159606 },
        { 105, 55690 },
        { 106, 159628 },
        { 107, 120583 },
        { 108, 159626 },
        { 109, 55692 },
        { 110, 119873 },
        { 111, 159624 },
        { 112, 159627 },
        { 113, 120584 },
        { 114, 89489 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minorpriest",
      [GLYPH_DIFF] = {
        { 1, 145722 },
        { 2, 58009 },
        { 3, 126152 },
        { 4, 58228 },
        { 5, 126174 },
        { 6, 147072 },
        { 7, 57986 },
        { 8, 107906 },
        { 9, 57985 },
        { 10, 126745 },
        { 11, 120581 },
        { 12, 147776 },
        { 13, 126094 },
      },
    },
  },
}

data["CLASS_ROGUE"] = {
  name = "Rogue",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("ROGUE"),
      [ROGUE_DIFF] = {
        { 1, 76273 },
        { 2, 76297 },
        { 4, { id = 157442, level = "1" }, },
        { 5, { id = 82245, level = "1" }, },
        { 6, { id = 1752, level = "1" }, },
        { 7, { id = 121733, level = "1" }, },
        { 8, { id = 2098, level = "3" }, },
        { 9, { id = 1784, level = "5" }, },
        { 10, { id = 8676, level = "6" }, },
        { 11, { id = 5277, level = "8" }, },
        { 12, { id = 2823, level = "10" }, },
        { 13, { id = 6770, level = "12" }, },
        { 14, { id = 5171, level = "14" }, },
        { 15, { id = 921, level = "15" }, },
        { 16, { id = 73651, level = "16" }, },
        { 17, { id = 1766, level = "18" }, },
        { 18, { id = 3408, level = "20" }, },
        { 19, { id = 1776, level = "22" }, },
        { 20, { id = 1804, level = "24" }, },
        { 21, { id = 2983, level = "26" }, },
        { 22, { id = 1725, level = "28" }, },
        { 23, { id = 1833, level = "30" }, },
        { 24, { id = 113742, level = "30" }, },
        { 25, { id = 8679, level = "30" }, },
        { 26, { id = 1856, level = "34" }, },
        { 27, { id = 2094, level = "38" }, },
        { 28, { id = 408, level = "40" }, },
        { 29, { id = 2836, level = "42" }, },
        { 30, { id = 1966, level = "44" }, },
        { 101, { id = 703, level = "48" }, },
        { 102, { id = 1860, level = "48" }, },
        { 103, { id = 31224, level = "58" }, },
        { 104, { id = 31209, level = "62" }, },
        { 105, { id = 14185, level = "68" }, },
        { 106, { id = 5938, level = "74" }, },
        { 107, { id = 114018, level = "76" }, },
        { 108, { id = 57934, level = "78" }, },
        { 109, { id = 121411, level = "83" }, },
        { 110, { id = 76577, level = "85" }, },
      },
    },
    {
      name = "Assassination",
      CoinTexture = "texture:Interface\\Icons\\ability_rogue_eviscerate",
      [ROGUE_DIFF] = {
        { 1, { id = 157442, level = "1" }, },
        { 2, { id = 82245, level = "1" }, },
        { 3, { id = 1752, level = "1" }, },
        { 4, { id = 121733, level = "1" }, },
        { 5, { id = 2098, level = "3" }, },
        { 6, { id = 1784, level = "5" }, },
        { 7, { id = 8676, level = "6" }, },
        { 8, { id = 5277, level = "8" }, },
        { 9, { id = 84601, level = "10" }, },
        { 10, { id = 2823, level = "10" }, },
        { 11, { id = 14117, level = "10" }, },
        { 12, { id = 1329, level = "10" }, },
        { 13, { id = 79134, level = "10" }, },
        { 14, { id = 6770, level = "12" }, },
        { 15, { id = 5171, level = "14" }, },
        { 16, { id = 921, level = "15" }, },
        { 17, { id = 73651, level = "16" }, },
        { 18, { id = 1766, level = "18" }, },
        { 19, { id = 3408, level = "20" }, },
        { 20, { id = 51667, level = "20" }, },
        { 21, { id = 32645, level = "20" }, },
        { 22, { id = 1776, level = "22" }, },
        { 23, { id = 1804, level = "24" }, },
        { 24, { id = 2983, level = "26" }, },
        { 25, { id = 1725, level = "28" }, },
        { 26, { id = 1833, level = "30" }, },
        { 27, { id = 14190, level = "30" }, },
        { 28, { id = 113742, level = "30" }, },
        { 29, { id = 8679, level = "30" }, },
        { 30, { id = 1856, level = "34" }, },
        { 101, { id = 2094, level = "38" }, },
        { 102, { id = 121152, level = "40" }, },
        { 103, { id = 111240, level = "40" }, },
        { 104, { id = 408, level = "40" }, },
        { 105, { id = 2836, level = "42" }, },
        { 106, { id = 1966, level = "44" }, },
        { 107, { id = 1943, level = "46" }, },
        { 108, { id = 703, level = "48" }, },
        { 109, { id = 1860, level = "48" }, },
        { 110, { id = 58423, level = "54" }, },
        { 111, { id = 31224, level = "58" }, },
        { 112, { id = 31209, level = "62" }, },
        { 113, { id = 51723, level = "66" }, },
        { 114, { id = 14185, level = "68" }, },
        { 115, { id = 5938, level = "74" }, },
        { 116, { id = 114018, level = "76" }, },
        { 117, { id = 57934, level = "78" }, },
        { 118, { id = 76803, level = "80", rank = MASTERY }, },
        { 119, { id = 79140, level = "80" }, },
        { 120, { id = 121411, level = "83" }, },
        { 121, { id = 76577, level = "85" }, },
        { 122, { id = 165390, level = "90" }, },
        { 123, { id = 157569, level = "92+", rank = DRAENORPERK }, },
        { 124, { id = 157561, level = "92+", rank = DRAENORPERK }, },
        { 125, { id = 157514, level = "92+", rank = DRAENORPERK }, },
        { 126, { id = 157513, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Combat",
      CoinTexture = "texture:Interface\\Icons\\ability_backstab",
      [ROGUE_DIFF] = {
        { 1, { id = 157442, level = "1" }, },
        { 2, { id = 82245, level = "1" }, },
        { 3, { id = 1752, level = "1" }, },
        { 4, { id = 121733, level = "1" }, },
        { 5, { id = 2098, level = "3" }, },
        { 6, { id = 1784, level = "5" }, },
        { 7, { id = 8676, level = "6" }, },
        { 8, { id = 5277, level = "8" }, },
        { 9, { id = 13877, level = "10" }, },
        { 10, { id = 2823, level = "10" }, },
        { 11, { id = 6770, level = "12" }, },
        { 12, { id = 5171, level = "14" }, },
        { 13, { id = 921, level = "15" }, },
        { 14, { id = 73651, level = "16" }, },
        { 15, { id = 1766, level = "18" }, },
        { 16, { id = 3408, level = "20" }, },
        { 17, { id = 84617, level = "20" }, },
        { 18, { id = 1776, level = "22" }, },
        { 19, { id = 1804, level = "24" }, },
        { 20, { id = 2983, level = "26" }, },
        { 21, { id = 1725, level = "28" }, },
        { 22, { id = 1833, level = "30" }, },
        { 23, { id = 35551, level = "30" }, },
        { 24, { id = 113742, level = "30" }, },
        { 25, { id = 8679, level = "30" }, },
        { 26, { id = 14161, level = "32" }, },
        { 27, { id = 1856, level = "34" }, },
        { 28, { id = 2094, level = "38" }, },
        { 29, { id = 13750, level = "40" }, },
        { 30, { id = 408, level = "40" }, },
        { 101, { id = 2836, level = "42" }, },
        { 102, { id = 1966, level = "44" }, },
        { 103, { id = 703, level = "48" }, },
        { 104, { id = 1860, level = "48" }, },
        { 105, { id = 31224, level = "58" }, },
        { 106, { id = 84654, level = "60" }, },
        { 107, { id = 31209, level = "62" }, },
        { 108, { id = 14185, level = "68" }, },
        { 109, { id = 5938, level = "74" }, },
        { 110, { id = 114018, level = "76" }, },
        { 111, { id = 57934, level = "78" }, },
        { 112, { id = 51690, level = "80" }, },
        { 113, { id = 76806, level = "80", rank = MASTERY }, },
        { 114, { id = 121411, level = "83" }, },
        { 115, { id = 76577, level = "85" }, },
        { 116, { id = 157581, level = "92+", rank = DRAENORPERK }, },
        { 117, { id = 157615, level = "92+", rank = DRAENORPERK }, },
        { 118, { id = 157660, level = "92+", rank = DRAENORPERK }, },
        { 119, { id = 157605, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Subtlety",
      CoinTexture = "texture:Interface\\Icons\\ability_stealth",
      [ROGUE_DIFF] = {
        { 1, { id = 157442, level = "1" }, },
        { 2, { id = 82245, level = "1" }, },
        { 3, { id = 1752, level = "1" }, },
        { 4, { id = 121733, level = "1" }, },
        { 5, { id = 2098, level = "3" }, },
        { 6, { id = 1784, level = "5" }, },
        { 7, { id = 8676, level = "6" }, },
        { 8, { id = 5277, level = "8" }, },
        { 9, { id = 2823, level = "10" }, },
        { 10, { id = 79152, level = "10" }, },
        { 11, { id = 91023, level = "10" }, },
        { 12, { id = 16511, level = "10" }, },
        { 13, { id = 31223, level = "10" }, },
        { 14, { id = 31220, level = "10" }, },
        { 15, { id = 6770, level = "12" }, },
        { 16, { id = 5171, level = "14" }, },
        { 17, { id = 921, level = "15" }, },
        { 18, { id = 73651, level = "16" }, },
        { 19, { id = 1766, level = "18" }, },
        { 20, { id = 3408, level = "20" }, },
        { 21, { id = 1776, level = "22" }, },
        { 22, { id = 1804, level = "24" }, },
        { 23, { id = 2983, level = "26" }, },
        { 24, { id = 1725, level = "28" }, },
        { 25, { id = 1833, level = "30" }, },
        { 26, { id = 14183, level = "30" }, },
        { 27, { id = 113742, level = "30" }, },
        { 28, { id = 8679, level = "30" }, },
        { 29, { id = 1856, level = "34" }, },
        { 30, { id = 2094, level = "38" }, },
        { 101, { id = 53, level = "40" }, },
        { 102, { id = 408, level = "40" }, },
        { 103, { id = 2836, level = "42" }, },
        { 104, { id = 1966, level = "44" }, },
        { 105, { id = 1943, level = "46" }, },
        { 106, { id = 703, level = "48" }, },
        { 107, { id = 1860, level = "48" }, },
        { 108, { id = 51701, level = "50" }, },
        { 109, { id = 58423, level = "54" }, },
        { 110, { id = 31224, level = "58" }, },
        { 111, { id = 79147, level = "60" }, },
        { 112, { id = 31209, level = "62" }, },
        { 113, { id = 51723, level = "66" }, },
        { 114, { id = 14185, level = "68" }, },
        { 115, { id = 5938, level = "74" }, },
        { 116, { id = 114018, level = "76" }, },
        { 117, { id = 57934, level = "78" }, },
        { 118, { id = 76808, level = "80", rank = MASTERY }, },
        { 119, { id = 51713, level = "80" }, },
        { 120, { id = 121411, level = "83" }, },
        { 121, { id = 76577, level = "85" }, },
        { 122, { id = 157671, level = "92+", rank = DRAENORPERK }, },
        { 123, { id = 157669, level = "92+", rank = DRAENORPERK }, },
        { 124, { id = 157704, level = "92+", rank = DRAENORPERK }, },
        { 125, { id = 157666, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [ROGUE_ASS_DIFF] = {
        { 1, { id = 14062, level = "15" }, },
        { 2, { id = 108208, level = "15" }, },
        { 3, { id = 108209, level = "15" }, },
        { 5, { id = 26679, level = "30" }, },
        { 6, { id = 108210, level = "30" }, },
        { 7, { id = 74001, level = "30" }, },
        { 9, { id = 31230, level = "45" }, },
        { 10, { id = 108211, level = "45" }, },
        { 11, { id = 79008, level = "45" }, },
        { 13, { id = 138106, level = "60" }, },
        { 14, { id = 36554, level = "60" }, },
        { 15, { id = 108212, level = "60" }, },
        { 16, { id = 131511, level = "75" }, },
        { 17, { id = 154904, level = "75" }, },
        { 18, { id = 108216, level = "75" }, },
        { 20, { id = 114014, level = "90" }, },
        { 21, { id = 137619, level = "90" }, },
        { 22, { id = 114015, level = "90" }, },
        { 24, { id = 152152, level = "100" }, },
        { 25, { id = 152151, level = "100" }, },
        { 26, { id = 152150, level = "100" }, },
      },
      [ROGUE_COMBAT_DIFF] = {
        { 1, { id = 14062, level = "15" }, },
        { 2, { id = 108208, level = "15" }, },
        { 3, { id = 108209, level = "15" }, },
        { 5, { id = 26679, level = "30" }, },
        { 6, { id = 108210, level = "30" }, },
        { 7, { id = 74001, level = "30" }, },
        { 9, { id = 31230, level = "45" }, },
        { 10, { id = 108211, level = "45" }, },
        { 11, { id = 79008, level = "45" }, },
        { 13, { id = 138106, level = "60" }, },
        { 14, { id = 36554, level = "60" }, },
        { 15, { id = 108212, level = "60" }, },
        { 16, { id = 131511, level = "75" }, },
        { 17, { id = 154904, level = "75" }, },
        { 18, { id = 108216, level = "75" }, },
        { 20, { id = 114014, level = "90" }, },
        { 21, { id = 137619, level = "90" }, },
        { 22, { id = 114015, level = "90" }, },
        { 24, { id = 152152, level = "100" }, },
        { 25, { id = 152151, level = "100" }, },
        { 26, { id = 152150, level = "100" }, },
      },
      [ROGUE_SUBTLETY_DIFF] = {
        { 1, { id = 14062, level = "15" }, },
        { 2, { id = 108208, level = "15" }, },
        { 3, { id = 108209, level = "15" }, },
        { 5, { id = 26679, level = "30" }, },
        { 6, { id = 108210, level = "30" }, },
        { 7, { id = 74001, level = "30" }, },
        { 9, { id = 31230, level = "45" }, },
        { 10, { id = 108211, level = "45" }, },
        { 11, { id = 79008, level = "45" }, },
        { 13, { id = 138106, level = "60" }, },
        { 14, { id = 36554, level = "60" }, },
        { 15, { id = 108212, level = "60" }, },
        { 16, { id = 131511, level = "75" }, },
        { 17, { id = 154904, level = "75" }, },
        { 18, { id = 108216, level = "75" }, },
        { 20, { id = 114014, level = "90" }, },
        { 21, { id = 137619, level = "90" }, },
        { 22, { id = 114015, level = "90" }, },
        { 24, { id = 152152, level = "100" }, },
        { 25, { id = 152151, level = "100" }, },
        { 26, { id = 152150, level = "100" }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majorrogue",
      [GLYPH_DIFF] = {
        { 1, 56813 },
        { 2, 56818 },
        { 3, 91299 },
        { 4, 56801 },
        { 5, 63269 },
        { 6, 63254 },
        { 7, 159638 },
        { 8, 159635 },
        { 9, 159634 },
        { 10, 159636 },
        { 11, 56799 },
        { 12, 56804 },
        { 13, 56812 },
        { 14, 56809 },
        { 15, 146631 },
        { 16, 56805 },
        { 17, 146625 },
        { 18, 56806 },
        { 19, 56810 },
        { 20, 56819 },
        { 21, 56811 },
        { 22, 63253 },
        { 23, 89758 },
        { 24, 63249 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minorrogue",
      [GLYPH_DIFF] = {
        { 1, 58039 },
        { 2, 56800 },
        { 3, 125044 },
        { 4, 63268 },
        { 5, 58032 },
        { 6, 56807 },
        { 7, 146961 },
        { 8, 63252 },
        { 9, 58027 },
        { 10, 58017 },
        { 11, 58038 },
        { 12, 58033 },
        { 13, 146960 },
      },
    },
  },
}

data["CLASS_SHAMAN"] = {
  name = "Shaman",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("SHAMAN"),
      [SHAMAN_DIFF] = {
        { 1, 76272 },
        { 2, 76296 },
        { 4, { id = 107, level = "1" }, },
        { 5, { id = 403, level = "1" }, },
        { 6, { id = 73899, level = "3" }, },
        { 7, { id = 8004, level = "7" }, },
        { 8, { id = 324, level = "8" }, },
        { 9, { id = 8050, level = "12" }, },
        { 10, { id = 370, level = "12" }, },
        { 11, { id = 2008, level = "14" }, },
        { 12, { id = 2645, level = "15" }, },
        { 13, { id = 3599, level = "16" }, },
        { 14, { id = 57994, level = "16" }, },
        { 15, { id = 51886, level = "18" }, },
        { 16, { id = 8056, level = "22" }, },
        { 17, { id = 546, level = "24" }, },
        { 18, { id = 2484, level = "26" }, },
        { 19, { id = 421, level = "28" }, },
        { 20, { id = 5394, level = "30" }, },
        { 21, { id = 36936, level = "30" }, },
        { 22, { id = 20608, level = "32" }, },
        { 23, { id = 556, level = "34" }, },
        { 24, { id = 6196, level = "36" }, },
        { 25, { id = 8177, level = "38" }, },
        { 26, { id = 8143, level = "54" }, },
        { 27, { id = 2062, level = "58" }, },
        { 28, { id = 73920, level = "60" }, },
        { 29, { id = 108269, level = "63" }, },
        { 30, { id = 2894, level = "66" }, },
        { 101, { id = 2825, level = "70" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 102, { id = 32182, level = "70" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 103, { id = 51514, level = "75" }, },
        { 104, { id = 116956, level = "80" }, },
      },
    },
    {
      name = "Elemental",
      CoinTexture = "texture:Interface\\Icons\\spell_nature_lightning",
      [SHAMAN_DIFF] = {
        { 1, { id = 107, level = "1" }, },
        { 2, { id = 403, level = "1" }, },
        { 3, { id = 73899, level = "3" }, },
        { 4, { id = 8042, level = "6" }, },
        { 5, { id = 8004, level = "7" }, },
        { 6, { id = 324, level = "8" }, },
        { 7, { id = 60188, level = "10" }, },
        { 8, { id = 29000, level = "10" }, },
        { 9, { id = 62099, level = "10" }, },
        { 10, { id = 123099, level = "10" }, },
        { 11, { id = 51490, level = "10" }, },
        { 12, { id = 8050, level = "12" }, },
        { 13, { id = 370, level = "12" }, },
        { 14, { id = 2008, level = "14" }, },
        { 15, { id = 2645, level = "15" }, },
        { 16, { id = 3599, level = "16" }, },
        { 17, { id = 57994, level = "16" }, },
        { 18, { id = 51886, level = "18" }, },
        { 19, { id = 88766, level = "20" }, },
        { 20, { id = 8056, level = "22" }, },
        { 21, { id = 546, level = "24" }, },
        { 22, { id = 2484, level = "26" }, },
        { 23, { id = 421, level = "28" }, },
        { 24, { id = 5394, level = "30" }, },
        { 25, { id = 36936, level = "30" }, },
        { 26, { id = 20608, level = "32" }, },
        { 27, { id = 556, level = "34" }, },
        { 28, { id = 51505, level = "34" }, },
        { 29, { id = 6196, level = "36" }, },
        { 30, { id = 8177, level = "38" }, },
        { 101, { id = 77756, level = "50" }, },
        { 102, { id = 8143, level = "54" }, },
        { 103, { id = 2062, level = "58" }, },
        { 104, { id = 61882, level = "60" }, },
        { 105, { id = 73920, level = "60" }, },
        { 106, { id = 108269, level = "63" }, },
        { 107, { id = 30823, level = "65" }, },
        { 108, { id = 2894, level = "66" }, },
        { 109, { id = 2825, level = "70" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 110, { id = 32182, level = "70" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 111, { id = 51514, level = "75" }, },
        { 112, { id = 116956, level = "80" }, },
        { 113, { id = 170374, level = "80", rank = MASTERY }, },
        { 114, { id = 165462, level = "81" }, },
        { 115, { id = 79206, level = "85" }, },
        { 116, { id = 165339, level = "87" }, },
        { 117, { id = 165399, level = "90" }, },
        { 118, { id = 157765, level = "92+", rank = DRAENORPERK }, },
        { 119, { id = 157784, level = "92+", rank = DRAENORPERK }, },
        { 120, { id = 157774, level = "92+", rank = DRAENORPERK }, },
        { 121, { id = 157764, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Enhancement",
      CoinTexture = "texture:Interface\\Icons\\spell_shaman_improvedstormstrike",
      [SHAMAN_DIFF] = {
        { 1, { id = 107, level = "1" }, },
        { 2, { id = 157444, level = "1" }, },
        { 3, { id = 403, level = "1" }, },
        { 4, { id = 73899, level = "3" }, },
        { 5, { id = 8004, level = "7" }, },
        { 6, { id = 324, level = "8" }, },
        { 7, { id = 86629, level = "10" }, },
        { 8, { id = 10400, level = "10" }, },
        { 9, { id = 60103, level = "10" }, },
        { 10, { id = 30814, level = "10" }, },
        { 11, { id = 51522, level = "10" }, },
        { 12, { id = 8050, level = "12" }, },
        { 13, { id = 370, level = "12" }, },
        { 14, { id = 2008, level = "14" }, },
        { 15, { id = 2645, level = "15" }, },
        { 16, { id = 3599, level = "16" }, },
        { 17, { id = 57994, level = "16" }, },
        { 18, { id = 51886, level = "18" }, },
        { 19, { id = 16282, level = "20" }, },
        { 20, { id = 8056, level = "22" }, },
        { 21, { id = 546, level = "24" }, },
        { 22, { id = 2484, level = "26" }, },
        { 23, { id = 17364, level = "26" }, },
        { 24, { id = 421, level = "28" }, },
        { 25, { id = 166221, level = "30" }, },
        { 26, { id = 5394, level = "30" }, },
        { 27, { id = 36936, level = "30" }, },
        { 28, { id = 33757, level = "30" }, },
        { 29, { id = 20608, level = "32" }, },
        { 30, { id = 556, level = "34" }, },
        { 101, { id = 6196, level = "36" }, },
        { 102, { id = 8190, level = "36" }, },
        { 103, { id = 8177, level = "38" }, },
        { 104, { id = 1535, level = "44" }, },
        { 105, { id = 51530, level = "50" }, },
        { 106, { id = 8143, level = "54" }, },
        { 107, { id = 2062, level = "58" }, },
        { 108, { id = 51533, level = "60" }, },
        { 109, { id = 73920, level = "60" }, },
        { 110, { id = 58875, level = "60" }, },
        { 111, { id = 108269, level = "63" }, },
        { 112, { id = 30823, level = "65" }, },
        { 113, { id = 2894, level = "66" }, },
        { 114, { id = 2825, level = "70" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 115, { id = 32182, level = "70" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 116, { id = 51514, level = "75" }, },
        { 117, { id = 116956, level = "80" }, },
        { 118, { id = 77223, level = "80", rank = MASTERY }, },
        { 119, { id = 73680, level = "81" }, },
        { 120, { id = 165341, level = "87" }, },
        { 121, { id = 165368, level = "90" }, },
        { 122, { id = 157784, level = "92+", rank = DRAENORPERK }, },
        { 123, { id = 157804, level = "92+", rank = DRAENORPERK }, },
        { 124, { id = 157807, level = "92+", rank = DRAENORPERK }, },
        { 125, { id = 157764, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Restoration",
      CoinTexture = "texture:Interface\\Icons\\spell_nature_magicimmunity",
      [SHAMAN_DIFF] = {
        { 1, { id = 107, level = "1" }, },
        { 2, { id = 403, level = "1" }, },
        { 3, { id = 73899, level = "3" }, },
        { 4, { id = 8004, level = "7" }, },
        { 5, { id = 324, level = "8" }, },
        { 6, { id = 95862, level = "10" }, },
        { 7, { id = 16213, level = "10" }, },
        { 8, { id = 61295, level = "10" }, },
        { 9, { id = 112858, level = "10" }, },
        { 10, { id = 8050, level = "12" }, },
        { 11, { id = 370, level = "12" }, },
        { 12, { id = 2008, level = "14" }, },
        { 13, { id = 2645, level = "15" }, },
        { 14, { id = 3599, level = "16" }, },
        { 15, { id = 57994, level = "16" }, },
        { 16, { id = 51886, level = "18" }, },
        { 17, { id = 77130, level = "18" }, },
        { 18, { id = 52127, level = "20" }, },
        { 19, { id = 8056, level = "22" }, },
        { 20, { id = 546, level = "24" }, },
        { 21, { id = 974, level = "26" }, },
        { 22, { id = 2484, level = "26" }, },
        { 23, { id = 421, level = "28" }, },
        { 24, { id = 5394, level = "30" }, },
        { 25, { id = 36936, level = "30" }, },
        { 26, { id = 20608, level = "32" }, },
        { 27, { id = 556, level = "34" }, },
        { 28, { id = 51505, level = "34" }, },
        { 29, { id = 6196, level = "36" }, },
        { 30, { id = 8177, level = "38" }, },
        { 101, { id = 16196, level = "40" }, },
        { 102, { id = 1064, level = "44" }, },
        { 103, { id = 51564, level = "50" }, },
        { 104, { id = 8143, level = "54" }, },
        { 105, { id = 2062, level = "58" }, },
        { 106, { id = 73920, level = "60" }, },
        { 107, { id = 77472, level = "60" }, },
        { 108, { id = 108269, level = "63" }, },
        { 109, { id = 108280, level = "65" }, },
        { 110, { id = 2894, level = "66" }, },
        { 111, { id = 2825, level = "70" }, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 112, { id = 32182, level = "70" }, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 113, { id = 98008, level = "70" }, },
        { 114, { id = 51514, level = "75" }, },
        { 115, { id = 116956, level = "80" }, },
        { 116, { id = 77226, level = "80", rank = MASTERY }, },
        { 117, { id = 79206, level = "85" }, },
        { 118, { id = 165344, level = "87" }, },
        { 119, { id = 165391, level = "90" }, },
        { 120, { id = 157784, level = "92+", rank = DRAENORPERK }, },
        { 121, { id = 157813, level = "92+", rank = DRAENORPERK }, },
        { 122, { id = 157764, level = "92+", rank = DRAENORPERK }, },
        { 123, { id = 157812, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [SHAMAN_ELE_DIFF] = {
        { 1, { id = 30884, level = "15" }, },
        { 2, { id = 108270, level = "15" }, },
        { 3, { id = 108271, level = "15" }, },
        { 5, { id = 63374, level = "30" }, },
        { 6, { id = 51485, level = "30" }, },
        { 7, { id = 108273, level = "30" }, },
        { 9, { id = 108285, level = "45" }, },
        { 10, { id = 108284, level = "45" }, },
        { 11, { id = 108287, level = "45" }, },
        { 13, { id = 16166, level = "60" }, },
        { 14, { id = 16188, level = "60" }, },
        { 15, { id = 108283, level = "60" }, },
        { 16, { id = 147074, level = "75" }, },
        { 17, { id = 108281, level = "75" }, },
        { 18, { id = 108282, level = "75" }, },
        { 20, { id = 165477, level = "90" }, },
        { 21, { id = 117013, level = "90" }, },
        { 22, { id = 117014, level = "90" }, },
        { 24, { id = 152257, level = "100" }, },
        { 25, { id = 152256, level = "100" }, },
        { 26, { id = 152255, level = "100" }, },
      },
      [SHAMAN_ENH_DIFF] = {
        { 1, { id = 30884, level = "15" }, },
        { 2, { id = 108270, level = "15" }, },
        { 3, { id = 108271, level = "15" }, },
        { 5, { id = 63374, level = "30" }, },
        { 6, { id = 51485, level = "30" }, },
        { 7, { id = 108273, level = "30" }, },
        { 9, { id = 108285, level = "45" }, },
        { 10, { id = 108284, level = "45" }, },
        { 11, { id = 108287, level = "45" }, },
        { 13, { id = 16166, level = "60" }, },
        { 14, { id = 16188, level = "60" }, },
        { 15, { id = 108283, level = "60" }, },
        { 16, { id = 147074, level = "75" }, },
        { 17, { id = 108281, level = "75" }, },
        { 18, { id = 108282, level = "75" }, },
        { 20, { id = 165477, level = "90" }, },
        { 21, { id = 117013, level = "90" }, },
        { 22, { id = 117014, level = "90" }, },
        { 24, { id = 152257, level = "100" }, },
        { 25, { id = 152256, level = "100" }, },
        { 26, { id = 152255, level = "100" }, },
      },
      [SHAMAN_RESTO_DIFF] = {
        { 1, { id = 30884, level = "15" }, },
        { 2, { id = 108270, level = "15" }, },
        { 3, { id = 108271, level = "15" }, },
        { 5, { id = 63374, level = "30" }, },
        { 6, { id = 51485, level = "30" }, },
        { 7, { id = 108273, level = "30" }, },
        { 9, { id = 108285, level = "45" }, },
        { 10, { id = 108284, level = "45" }, },
        { 11, { id = 108287, level = "45" }, },
        { 13, { id = 16166, level = "60" }, },
        { 14, { id = 16188, level = "60" }, },
        { 15, { id = 108283, level = "60" }, },
        { 16, { id = 147074, level = "75" }, },
        { 17, { id = 108281, level = "75" }, },
        { 18, { id = 108282, level = "75" }, },
        { 20, { id = 165477, level = "90" }, },
        { 21, { id = 117013, level = "90" }, },
        { 22, { id = 117014, level = "90" }, },
        { 24, { id = 157153, level = "100" }, },
        { 25, { id = 152256, level = "100" }, },
        { 26, { id = 157154, level = "100" }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majorshaman",
      [GLYPH_DIFF] = {
        { 1, 55442 },
        { 2, 55449 },
        { 3, 55452 },
        { 4, 55445 },
        { 5, 159640 },
        { 6, 147781 },
        { 7, 63271 },
        { 8, 55455 },
        { 9, 55450 },
        { 10, 55447 },
        { 11, 55443 },
        { 12, 161654 },
        { 13, 59289 },
        { 14, 159643 },
        { 15, 55441 },
        { 16, 55456 },
        { 17, 55440 },
        { 18, 63291 },
        { 19, 159644 },
        { 20, 101052 },
        { 21, 55439 },
        { 22, 147762 },
        { 23, 171933 },
        { 24, 159647 },
        { 25, 63273 },
        { 26, 63280 },
        { 27, 159648 },
        { 28, 159649 },
        { 29, 55454 },
        { 30, 159651 },
        { 101, 159650 },
        { 102, 55446 },
        { 103, 63270 },
        { 104, 55438 },
        { 105, 63298 },
        { 106, 55437 },
        { 107, 55436 },
        { 108, 55451 },
        { 109, 55453 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minorshaman",
      [GLYPH_DIFF] = {
        { 1, 147787 },
        { 2, 58058 },
        { 3, 63279 },
        { 4, 147788 },
        { 5, 58059 },
        { 6, 147772 },
        { 7, 159642 },
        { 8, 55444 },
        { 9, 147784 },
        { 10, 147707 },
        { 11, 147783 },
        { 12, 147770 },
        { 13, 147785 },
        { 14, 55448 },
        { 15, 58135 },
        { 16, 62132 },
        { 17, 58057 },
      },
    },
  },
}

data["CLASS_WARLOCK"] = {
  name = "Warlock",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("WARLOCK"),
      [WARLOCK_DIFF] = {
        { 1, 76277 },
        { 2, 76299 },
        { 4, { id = 686, level = "1" }, },
        { 5, { id = 5019, level = "1" }, },
        { 6, { id = 688, level = "1" }, },
        { 7, { id = 172, level = "3" }, },
        { 8, { id = 697, level = "8" }, },
        { 9, { id = 6201, level = "9" }, },
        { 10, { id = 5782, level = "14" }, },
        { 11, { id = 20707, level = "18" }, },
        { 12, { id = 5784, level = "20" }, },
        { 13, { id = 712, level = "20" }, },
        { 14, { id = 126, level = "22" }, },
        { 15, { id = 5697, level = "24" }, },
        { 16, { id = 101976, level = "27" }, },
        { 17, { id = 691, level = "29" }, },
        { 18, { id = 1098, level = "31" }, },
        { 19, { id = 710, level = "32" }, },
        { 20, { id = 23161, level = "40" }, },
        { 21, { id = 698, level = "42" }, },
        { 22, { id = 1122, level = "49" }, },
        { 23, { id = 119898, level = "56" }, },
        { 24, { id = 18540, level = "58" }, },
        { 25, { id = 104773, level = "64" }, },
        { 26, { id = 29858, level = "66" }, },
        { 27, { id = 29893, level = "68" }, },
        { 28, { id = 48018, level = "76" }, },
        { 29, { id = 48020, level = "76" }, },
        { 30, { id = 166928, level = "80" }, },
        { 101, { id = 109773, level = "82" }, },
        { 102, { id = 111771, level = "87" }, },
      },
    },
    {
      name = "Affliction",
      CoinTexture = "texture:Interface\\Icons\\spell_shadow_deathcoil",
      [WARLOCK_DIFF] = {
        { 1, { id = 686, level = "1" }, },
        { 2, { id = 5019, level = "1" }, },
        { 3, { id = 688, level = "1" }, },
        { 4, { id = 172, level = "3" }, },
        { 5, { id = 689, level = "7" }, },
        { 6, { id = 697, level = "8" }, },
        { 7, { id = 6201, level = "9" }, },
        { 8, { id = 108558, level = "10" }, },
        { 9, { id = 30108, level = "10" }, },
        { 10, { id = 755, level = "11" }, },
        { 11, { id = 5782, level = "14" }, },
        { 12, { id = 1454, level = "16" }, },
        { 13, { id = 20707, level = "18" }, },
        { 14, { id = 74434, level = "19" }, },
        { 15, { id = 5784, level = "20" }, },
        { 16, { id = 712, level = "20" }, },
        { 17, { id = 27243, level = "21" }, },
        { 18, { id = 126, level = "22" }, },
        { 19, { id = 103103, level = "24" }, },
        { 20, { id = 5697, level = "24" }, },
        { 21, { id = 101976, level = "27" }, },
        { 22, { id = 691, level = "29" }, },
        { 23, { id = 1098, level = "31" }, },
        { 24, { id = 710, level = "32" }, },
        { 25, { id = 980, level = "36" }, },
        { 26, { id = 23161, level = "40" }, },
        { 27, { id = 698, level = "42" }, },
        { 28, { id = 1122, level = "49" }, },
        { 29, { id = 119898, level = "56" }, },
        { 30, { id = 18540, level = "58" }, },
        { 101, { id = 48181, level = "60" }, },
        { 102, { id = 104773, level = "64" }, },
        { 103, { id = 29858, level = "66" }, },
        { 104, { id = 29893, level = "68" }, },
        { 105, { id = 48018, level = "76" }, },
        { 106, { id = 48020, level = "76" }, },
        { 107, { id = 86121, level = "79" }, },
        { 108, { id = 166928, level = "80" }, },
        { 109, { id = 77215, level = "80", rank = MASTERY }, },
        { 110, { id = 109773, level = "82" }, },
        { 111, { id = 113860, level = "84" }, },
        { 112, { id = 111771, level = "87" }, },
        { 113, { id = 165367, level = "90" }, },
        { 114, { id = 157078, level = "92+", rank = DRAENORPERK }, },
        { 115, { id = 157069, level = "92+", rank = DRAENORPERK }, },
        { 116, { id = 157072, level = "92+", rank = DRAENORPERK }, },
        { 117, { id = 157077, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Demonology",
      CoinTexture = "texture:Interface\\Icons\\spell_shadow_metamorphosis",
      [WARLOCK_DIFF] = {
        { 1, { id = 686, level = "1" }, },
        { 2, { id = 5019, level = "1" }, },
        { 3, { id = 688, level = "1" }, },
        { 4, { id = 172, level = "3" }, },
        { 5, { id = 689, level = "7" }, },
        { 6, { id = 697, level = "8" }, },
        { 7, { id = 6201, level = "9" }, },
        { 8, { id = 108869, level = "10" }, },
        { 9, { id = 104315, level = "10" }, },
        { 10, { id = 124913, level = "10" }, },
        { 11, { id = 103958, level = "10" }, },
        { 12, { id = 122351, level = "10" }, },
        { 13, { id = 755, level = "11" }, },
        { 14, { id = 109151, level = "12" }, },
        { 15, { id = 6353, level = "13" }, },
        { 16, { id = 5782, level = "14" }, },
        { 17, { id = 1454, level = "16" }, },
        { 18, { id = 20707, level = "18" }, },
        { 19, { id = 105174, level = "19" }, },
        { 20, { id = 5784, level = "20" }, },
        { 21, { id = 712, level = "20" }, },
        { 22, { id = 126, level = "22" }, },
        { 23, { id = 1949, level = "22" }, },
        { 24, { id = 5697, level = "24" }, },
        { 25, { id = 101976, level = "27" }, },
        { 26, { id = 691, level = "29" }, },
        { 27, { id = 1098, level = "31" }, },
        { 28, { id = 710, level = "32" }, },
        { 29, { id = 114592, level = "32" }, },
        { 30, { id = 23161, level = "40" }, },
        { 101, { id = 698, level = "42" }, },
        { 102, { id = 30146, level = "42" }, },
        { 103, { id = 1122, level = "49" }, },
        { 104, { id = 119898, level = "56" }, },
        { 105, { id = 18540, level = "58" }, },
        { 106, { id = 104773, level = "64" }, },
        { 107, { id = 29858, level = "66" }, },
        { 108, { id = 29893, level = "68" }, },
        { 109, { id = 48018, level = "76" }, },
        { 110, { id = 48020, level = "76" }, },
        { 111, { id = 166928, level = "80" }, },
        { 112, { id = 77219, level = "80" }, },
        { 113, { id = 109773, level = "82" }, },
        { 114, { id = 113861, level = "84" }, },
        { 115, { id = 111771, level = "87" }, },
        { 116, { id = 165392, level = "90" }, },
        { 117, { id = 157096, level = "92+" }, },
        { 118, { id = 157100, level = "92+" }, },
        { 119, { id = 157069, level = "92+" }, },
        { 120, { id = 157098, level = "92+" }, },
      },
    },
    {
      name = "Destruction",
      CoinTexture = "texture:Interface\\Icons\\spell_shadow_rainoffire",
      [WARLOCK_DIFF] = {
        { 1, { id = 686, level = "1" }, },
        { 2, { id = 5019, level = "1" }, },
        { 3, { id = 688, level = "1" }, },
        { 4, { id = 172, level = "3" }, },
        { 5, { id = 697, level = "8" }, },
        { 6, { id = 6201, level = "9" }, },
        { 7, { id = 108647, level = "10" }, },
        { 8, { id = 116858, level = "10" }, },
        { 9, { id = 111546, level = "10" }, },
        { 10, { id = 17962, level = "10" }, },
        { 11, { id = 29722, level = "10" }, },
        { 12, { id = 348, level = "12" }, },
        { 13, { id = 5782, level = "14" }, },
        { 14, { id = 114635, level = "15" }, },
        { 15, { id = 20707, level = "18" }, },
        { 16, { id = 5784, level = "20" }, },
        { 17, { id = 712, level = "20" }, },
        { 18, { id = 5740, level = "21" }, },
        { 19, { id = 126, level = "22" }, },
        { 20, { id = 5697, level = "24" }, },
        { 21, { id = 101976, level = "27" }, },
        { 22, { id = 691, level = "29" }, },
        { 23, { id = 1098, level = "31" }, },
        { 24, { id = 710, level = "32" }, },
        { 25, { id = 80240, level = "36" }, },
        { 26, { id = 23161, level = "40" }, },
        { 27, { id = 698, level = "42" }, },
        { 28, { id = 17877, level = "47" }, },
        { 29, { id = 1122, level = "49" }, },
        { 30, { id = 109784, level = "54" }, },
        { 101, { id = 108683, level = "54" }, },
        { 102, { id = 119898, level = "56" }, },
        { 103, { id = 18540, level = "58" }, },
        { 104, { id = 104773, level = "64" }, },
        { 105, { id = 29858, level = "66" }, },
        { 106, { id = 29893, level = "68" }, },
        { 107, { id = 117896, level = "69" }, },
        { 108, { id = 48018, level = "76" }, },
        { 109, { id = 48020, level = "76" }, },
        { 110, { id = 120451, level = "79" }, },
        { 111, { id = 166928, level = "80" }, },
        { 112, { id = 77220, level = "80", rank = MASTERY }, },
        { 113, { id = 109773, level = "82" }, },
        { 114, { id = 113858, level = "84" }, },
        { 115, { id = 111771, level = "87" }, },
        { 116, { id = 165363, level = "90" }, },
        { 117, { id = 157114, level = "92+", rank = DRAENORPERK }, },
        { 118, { id = 157103, level = "92+", rank = DRAENORPERK }, },
        { 119, { id = 157121, level = "92+", rank = DRAENORPERK }, },
        { 120, { id = 157126, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [WARLOCK_AFF_DIFF] = {
        { 1, { id = 108359, level = "15" }, },
        { 2, { id = 108370, level = "15" }, },
        { 3, { id = 108371, level = "15" }, },
        { 5, { id = 5484, level = "30" }, },
        { 6, { id = 6789, level = "30" }, },
        { 7, { id = 30283, level = "30" }, },
        { 9, { id = 108415, level = "45" }, },
        { 10, { id = 108416, level = "45" }, },
        { 11, { id = 110913, level = "45" }, },
        { 13, { id = 111397, level = "60" }, },
        { 14, { id = 111400, level = "60" }, },
        { 15, { id = 108482, level = "60" }, },
        { 16, { id = 108499, level = "75" }, },
        { 17, { id = 108501, level = "75" }, },
        { 18, { id = 108503, level = "75" }, },
        { 20, { id = 108505, level = "90" }, },
        { 21, { id = 137587, level = "90" }, },
        { 22, { id = 108508, level = "90" }, },
        { 24, { id = 152109, level = "100" }, },
        { 25, { id = 152108, level = "100" }, },
        { 26, { id = 152107, level = "100" }, },
      },
      [WARLOCK_DEMO_DIFF] = {
        { 1, { id = 108359, level = "15" }, },
        { 2, { id = 108370, level = "15" }, },
        { 3, { id = 108371, level = "15" }, },
        { 5, { id = 5484, level = "30" }, },
        { 6, { id = 6789, level = "30" }, },
        { 7, { id = 30283, level = "30" }, },
        { 9, { id = 108415, level = "45" }, },
        { 10, { id = 108416, level = "45" }, },
        { 11, { id = 110913, level = "45" }, },
        { 13, { id = 111397, level = "60" }, },
        { 14, { id = 111400, level = "60" }, },
        { 15, { id = 108482, level = "60" }, },
        { 16, { id = 108499, level = "75" }, },
        { 17, { id = 108501, level = "75" }, },
        { 18, { id = 171975, level = "75" }, },
        { 20, { id = 108505, level = "90" }, },
        { 21, { id = 137587, level = "90" }, },
        { 22, { id = 108508, level = "90" }, },
        { 24, { id = 157695, level = "100" }, },
        { 25, { id = 152108, level = "100" }, },
        { 26, { id = 152107, level = "100" }, },
      },
      [WARLOCK_DESTRO_DIFF] = {
        { 1, { id = 108359, level = "15" }, },
        { 2, { id = 108370, level = "15" }, },
        { 3, { id = 174848, level = "15" }, },
        { 5, { id = 5484, level = "30" }, },
        { 6, { id = 6789, level = "30" }, },
        { 7, { id = 30283, level = "30" }, },
        { 9, { id = 108415, level = "45" }, },
        { 10, { id = 108416, level = "45" }, },
        { 11, { id = 110913, level = "45" }, },
        { 13, { id = 111397, level = "60" }, },
        { 14, { id = 111400, level = "60" }, },
        { 15, { id = 108482, level = "60" }, },
        { 16, { id = 108499, level = "75" }, },
        { 17, { id = 108501, level = "75" }, },
        { 18, { id = 108503, level = "75" }, },
        { 20, { id = 108505, level = "90" }, },
        { 21, { id = 137587, level = "90" }, },
        { 22, { id = 108508, level = "90" }, },
        { 24, { id = 157696, level = "100" }, },
        { 25, { id = 152108, level = "100" }, },
        { 26, { id = 152107, level = "100" }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majorwarlock",
      [GLYPH_DIFF] = {
        { 1, 56235 },
        { 2, 159665 },
        { 3, 56249 },
        { 4, 63309 },
        { 5, 63302 },
        { 6, 63304 },
        { 7, 148683 },
        { 8, 56244 },
        { 9, 146962 },
        { 10, 56224 },
        { 11, 56242 },
        { 12, 159669 },
        { 13, 63320 },
        { 14, 159688 },
        { 15, 56218 },
        { 16, 58070 },
        { 17, 56226 },
        { 18, 159691 },
        { 19, 56231 },
        { 20, 159697 },
        { 21, 159693 },
        { 22, 146964 },
        { 23, 56233 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minorwarlock",
      [GLYPH_DIFF] = {
        { 1, 63312 },
        { 2, 58107 },
        { 3, 58081 },
        { 4, 56247 },
        { 5, 56246 },
        { 6, 135557 },
        { 7, 56248 },
        { 8, 56238 },
        { 9, 159680 },
        { 10, 56232 },
        { 11, 56240 },
        { 12, 58094 },
        { 13, 56217 },
        { 14, 58079 },
        { 15, 56241 },
      },
    },
    {
      name = "Pet Abilities",
      CoinTexture = "texture:Interface\\Icons\\spell_shadow_summonfelhunter",
      [WARLOCK_PET_NORMAL_DIFF] = {
        { 1, { id = 32233 }, },
        
        { 3, { id = 89766, rank = COLOR_PET_FAMILY.."Felguard" }, },
        { 4, { id = 89751, rank = COLOR_PET_FAMILY.."Felguard" }, },
        { 5, { id = 30213, rank = COLOR_PET_FAMILY.."Felguard" }, },
        { 6, { id = 30151, rank = COLOR_PET_FAMILY.."Felguard" }, },
        { 7, { id = 134477, rank = COLOR_PET_FAMILY.."Felguard" }, },
        
        { 9, { id = 19505, rank = COLOR_PET_FAMILY.."Felhunter" }, },
        { 10, { id = 54049, rank = COLOR_PET_FAMILY.."Felhunter" }, },
        { 11, { id = 19647, rank = COLOR_PET_FAMILY.."Felhunter" }, },
        
        { 16, { id = 119899, rank = COLOR_PET_FAMILY.."Imp" }, },
        { 17, { id = 3110, rank = COLOR_PET_FAMILY.."Imp" }, },
        { 18, { id = 89792, rank = COLOR_PET_FAMILY.."Imp" }, },
        { 19, { id = 89808, rank = COLOR_PET_FAMILY.."Imp" }, },
        
        { 21, { id = 7814, rank = COLOR_PET_FAMILY.."Succubus" }, },
        { 22, { id = 7870, rank = COLOR_PET_FAMILY.."Succubus" }, },
        { 23, { id = 6358, rank = COLOR_PET_FAMILY.."Succubus" }, },
        { 24, { id = 6360, rank = COLOR_PET_FAMILY.."Succubus" }, },

        { 26, { id = 17767, rank = COLOR_PET_FAMILY.."Voidwalker" }, },
        { 27, { id = 115232, rank = COLOR_PET_FAMILY.."Voidwalker" }, },
        { 28, { id = 17735, rank = COLOR_PET_FAMILY.."Voidwalker" }, },
        { 29, { id = 112042, rank = COLOR_PET_FAMILY.."Voidwalker" }, },
        { 30, { id = 3716, rank = COLOR_PET_FAMILY.."Voidwalker" }, },
      },
      [WARLOCK_PET_GOS_DIFF] = {
        { 1, { id = 115578, rank = "Passive" }, },
        
        { 3, { id = 89766, rank = COLOR_PET_FAMILY.."Wrathguard" }, },
        { 4, { id = 115831, rank = COLOR_PET_FAMILY.."Wrathguard" }, },
        { 5, { id = 115625, rank = COLOR_PET_FAMILY.."Wrathguard" }, },
        { 6, { id = 30151, rank = COLOR_PET_FAMILY.."Wrathguard" }, },
        { 7, { id = 134477, rank = COLOR_PET_FAMILY.."Wrathguard" }, },
        
        { 9, { id = 115284, rank = COLOR_PET_FAMILY.."Observer" }, },
        { 10, { id = 115778, rank = COLOR_PET_FAMILY.."Observer" }, },
        { 11, { id = 115781, rank = COLOR_PET_FAMILY.."Observer" }, },
        
        { 16, { id = 119899, rank = COLOR_PET_FAMILY.."Fel Imp" }, },
        { 17, { id = 115746, rank = COLOR_PET_FAMILY.."Fel Imp" }, },
        { 18, { id = 89792, rank = COLOR_PET_FAMILY.."Fel Imp" }, },
        { 19, { id = 115276, rank = COLOR_PET_FAMILY.."Fel Imp" }, },
        
        { 21, { id = 115748, rank = COLOR_PET_FAMILY.."Shivarra" }, },
        { 22, { id = 7870, rank = COLOR_PET_FAMILY.."Shivarra" }, },
        { 23, { id = 115268, rank = COLOR_PET_FAMILY.."Shivarra" }, },
        { 24, { id = 115770, rank = COLOR_PET_FAMILY.."Shivarra" }, },

        { 26, { id = 17767, rank = COLOR_PET_FAMILY.."Voidlord" }, },
        { 27, { id = 115236, rank = COLOR_PET_FAMILY.."Voidlord" }, },
        { 28, { id = 17735, rank = COLOR_PET_FAMILY.."Voidlord" }, },
        { 29, { id = 112042, rank = COLOR_PET_FAMILY.."Voidlord" }, },
        { 30, { id = 170176, rank = COLOR_PET_FAMILY.."Voidlord" }, },
      },
    },
  },
}

data["CLASS_WARRIOR"] = {
  name = "Warrior",
  ContentType = CLASSES_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "General",
      CoinTexture = "texture:Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes"..coords("WARRIOR"),
      [WARRIOR_DIFF] = {
        { 1, 76268 },
        { 2, 76290 },
        { 4, { id = 2457, level = "1" }, },
        { 5, { id = 107, level = "1" }, },
        { 6, { id = 78, level = "1" }, },
        { 7, { id = 3127, level = "1" }, },
        { 8, { id = 156287, level = "1" }, },
        { 9, { id = 176318, level = "1" }, },
        { 10, { id = 145585, level = "1" }, },
        { 11, { id = 100, level = "3" }, },
        { 12, { id = 34428, level = "5" }, },
        { 13, { id = 163558, level = "7" }, },
        { 14, { id = 71, level = "9" }, },
        { 15, { id = 355, level = "12" }, },
        { 16, { id = 158836, level = "15" }, },
        { 17, { id = 156321, level = "18" }, },
        { 18, { id = 57755, level = "22" }, },
        { 19, { id = 6552, level = "24" }, },
        { 20, { id = 115767, level = "32" }, },
        { 21, { id = 1715, level = "36" }, },
        { 22, { id = 6673, level = "42" }, },
        { 23, { id = 5246, level = "52" }, },
        { 24, { id = 18499, level = "54" }, },
        { 25, { id = 23920, level = "66" }, },
        { 26, { id = 469, level = "68" }, },
        { 27, { id = 3411, level = "72" }, },
        { 28, { id = 64382, level = "74" }, },
        { 29, { id = 6544, level = "85" }, },
      },
    },
    {
      name = "Arms",
      CoinTexture = "texture:Interface\\Icons\\ability_warrior_savageblow",
      [WARRIOR_DIFF] = {
        { 1, { id = 2457, level = "1" }, },
        { 2, { id = 107, level = "1" }, },
        { 3, { id = 78, level = "1" }, },
        { 4, { id = 3127, level = "1" }, },
        { 5, { id = 156287, level = "1" }, },
        { 6, { id = 176318, level = "1" }, },
        { 7, { id = 145585, level = "1" }, },
        { 8, { id = 100, level = "3" }, },
        { 9, { id = 34428, level = "5" }, },
        { 10, { id = 163201, level = "7" }, },
        { 11, { id = 163558, level = "7" }, },
        { 12, { id = 772, level = "7" }, },
        { 13, { id = 71, level = "9" }, },
        { 14, { id = 12294, level = "10" }, },
        { 15, { id = 12712, level = "10" }, },
        { 16, { id = 355, level = "12" }, },
        { 17, { id = 6343, level = "14" }, },
        { 18, { id = 158836, level = "15" }, },
        { 19, { id = 156321, level = "18" }, },
        { 20, { id = 57755, level = "22" }, },
        { 21, { id = 6552, level = "24" }, },
        { 22, { id = 1680, level = "26" }, },
        { 23, { id = 115767, level = "32" }, },
        { 24, { id = 1715, level = "36" }, },
        { 25, { id = 6673, level = "42" }, },
        { 26, { id = 5246, level = "52" }, },
        { 27, { id = 18499, level = "54" }, },
        { 28, { id = 118038, level = "56" }, },
        { 29, { id = 12328, level = "60" }, },
        { 30, { id = 23920, level = "66" }, },
        { 101, { id = 469, level = "68" }, },
        { 102, { id = 3411, level = "72" }, },
        { 103, { id = 64382, level = "74" }, },
        { 104, { id = 167188, level = "80" }, },
        { 105, { id = 76838, level = "80", rank = MASTERY }, },
        { 106, { id = 167105, level = "81" }, },
        { 107, { id = 174926, level = "81" }, },
        { 108, { id = 97462, level = "83" }, },
        { 109, { id = 6544, level = "85" }, },
        { 110, { id = 1719, level = "87" }, },
        { 111, { id = 165365, level = "90" }, },
        { 112, { id = 174737, level = "92+", rank = DRAENORPERK }, },
        { 113, { id = 157461, level = "92+", rank = DRAENORPERK }, },
        { 114, { id = 157452, level = "92+", rank = DRAENORPERK }, },
        { 115, { id = 176051, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Fury",
      CoinTexture = "texture:Interface\\Icons\\ability_warrior_innerrage",
      [WARRIOR_DIFF] = {
        { 1, { id = 2457, level = "1" }, },
        { 2, { id = 107, level = "1" }, },
        { 3, { id = 78, level = "1" }, },
        { 4, { id = 3127, level = "1" }, },
        { 5, { id = 156287, level = "1" }, },
        { 6, { id = 176318, level = "1" }, },
        { 7, { id = 145585, level = "1" }, },
        { 8, { id = 100, level = "3" }, },
        { 9, { id = 34428, level = "5" }, },
        { 10, { id = 5308, level = "7" }, },
        { 11, { id = 163558, level = "7" }, },
        { 12, { id = 71, level = "9" }, },
        { 13, { id = 23881, level = "10" }, },
        { 14, { id = 23588, level = "10" }, },
        { 15, { id = 46917, level = "10" }, },
        { 16, { id = 355, level = "12" }, },
        { 17, { id = 13046, level = "14" }, },
        { 18, { id = 158836, level = "15" }, },
        { 19, { id = 156321, level = "18" }, },
        { 20, { id = 100130, level = "18" }, },
        { 21, { id = 12323, level = "19" }, },
        { 22, { id = 57755, level = "22" }, },
        { 23, { id = 6552, level = "24" }, },
        { 24, { id = 1680, level = "26" }, },
        { 25, { id = 85288, level = "30" }, },
        { 26, { id = 115767, level = "32" }, },
        { 27, { id = 1715, level = "36" }, },
        { 28, { id = 81099, level = "38" }, },
        { 29, { id = 6673, level = "42" }, },
        { 30, { id = 46915, level = "50" }, },
        { 101, { id = 5246, level = "52" }, },
        { 102, { id = 18499, level = "54" }, },
        { 103, { id = 118038, level = "56" }, },
        { 104, { id = 12950, level = "58" }, },
        { 105, { id = 23920, level = "66" }, },
        { 106, { id = 469, level = "68" }, },
        { 107, { id = 3411, level = "72" }, },
        { 108, { id = 64382, level = "74" }, },
        { 109, { id = 167188, level = "80" }, },
        { 110, { id = 76856, level = "80", rank = MASTERY }, },
        { 111, { id = 174926, level = "81" }, },
        { 112, { id = 97462, level = "83" }, },
        { 113, { id = 6544, level = "85" }, },
        { 114, { id = 1719, level = "87" }, },
        { 115, { id = 165383, level = "90" }, },
        { 116, { id = 157454, level = "92+", rank = DRAENORPERK }, },
        { 117, { id = 157473, level = "92+", rank = DRAENORPERK }, },
        { 118, { id = 157452, level = "92+", rank = DRAENORPERK }, },
        { 119, { id = 176051, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Protection",
      CoinTexture = "texture:Interface\\Icons\\ability_warrior_defensivestance",
      [WARRIOR_DIFF] = {
        { 1, { id = 2457, level = "1" }, },
        { 2, { id = 107, level = "1" }, },
        { 3, { id = 78, level = "1" }, },
        { 4, { id = 3127, level = "1" }, },
        { 5, { id = 156287, level = "1" }, },
        { 6, { id = 176318, level = "1" }, },
        { 7, { id = 145585, level = "1" }, },
        { 8, { id = 100, level = "3" }, },
        { 9, { id = 34428, level = "5" }, },
        { 10, { id = 5308, level = "7" }, },
        { 11, { id = 163558, level = "7" }, },
        { 12, { id = 71, level = "9" }, },
        { 13, { id = 161608, level = "10" }, },
        { 14, { id = 158298, level = "10" }, },
        { 15, { id = 23922, level = "10" }, },
        { 16, { id = 46953, level = "10" }, },
        { 17, { id = 122509, level = "10" }, },
        { 18, { id = 29144, level = "10" }, },
        { 19, { id = 355, level = "12" }, },
        { 20, { id = 13046, level = "14" }, },
        { 21, { id = 6343, level = "14" }, },
        { 22, { id = 158836, level = "15" }, },
        { 23, { id = 2565, level = "18" }, },
        { 24, { id = 156321, level = "18" }, },
        { 25, { id = 57755, level = "22" }, },
        { 26, { id = 6552, level = "24" }, },
        { 27, { id = 20243, level = "26" }, },
        { 28, { id = 6572, level = "30" }, },
        { 29, { id = 115767, level = "32" }, },
        { 30, { id = 1715, level = "36" }, },
        { 101, { id = 12975, level = "38" }, },
        { 102, { id = 6673, level = "42" }, },
        { 103, { id = 871, level = "48" }, },
        { 104, { id = 5246, level = "52" }, },
        { 105, { id = 18499, level = "54" }, },
        { 106, { id = 1160, level = "56" }, },
        { 107, { id = 84608, level = "60" }, },
        { 108, { id = 23920, level = "66" }, },
        { 109, { id = 469, level = "68" }, },
        { 110, { id = 3411, level = "72" }, },
        { 111, { id = 64382, level = "74" }, },
        { 112, { id = 161798, level = "76" }, },
        { 113, { id = 76857, level = "80", rank = MASTERY }, },
        { 114, { id = 6544, level = "85" }, },
        { 115, { id = 114192, level = "87" }, },
        { 116, { id = 159362, level = "90" }, },
        { 117, { id = 165393, level = "90" }, },
        { 118, { id = 157497, level = "92+", rank = DRAENORPERK }, },
        { 119, { id = 157494, level = "92+", rank = DRAENORPERK }, },
        { 120, { id = 157449, level = "92+", rank = DRAENORPERK }, },
        { 121, { id = 157479, level = "92+", rank = DRAENORPERK }, },
      },
    },
    {
      name = "Talents",
      CoinTexture = "texture:Interface\\Icons\\ability_marksmanship",
      [WARRIOR_ARMS_DIFF] = {
        { 1, { id = 103826, level = "15" }, },
        { 2, { id = 103827, level = "15" }, },
        { 3, { id = 103828, level = "15" }, },
        { 5, { id = 55694, level = "30" }, },
        { 6, { id = 29838, level = "30" }, },
        { 7, { id = 103840, level = "30" }, },
        { 9, { id = 56636, level = "45" }, },
        { 10, { id = 29725, level = "45" }, },
        { 11, { id = 1464, level = "45" }, },
        { 13, { id = 107570, level = "60" }, },
        { 14, { id = 46968, level = "60" }, },
        { 15, { id = 118000, level = "60" }, },
        { 16, { id = 114028, level = "75" }, },
        { 17, { id = 114029, level = "75" }, },
        { 18, { id = 114030, level = "75" }, },
        { 20, { id = 107574, level = "90" }, },
        { 21, { id = 12292, level = "90" }, },
        { 22, { id = 46924, level = "90" }, },
        { 24, { id = 152278, level = "100" }, },
        { 25, { id = 152277, level = "100" }, },
        { 26, { id = 176289, level = "100" }, },
      },
      [WARRIOR_FURY_DIFF] = {
        { 1, { id = 103826, level = "15" }, },
        { 2, { id = 103827, level = "15" }, },
        { 3, { id = 103828, level = "15" }, },
        { 5, { id = 55694, level = "30" }, },
        { 6, { id = 29838, level = "30" }, },
        { 7, { id = 103840, level = "30" }, },
        { 9, { id = 169679, level = "45" }, },
        { 10, { id = 29725, level = "45" }, },
        { 11, { id = 169683, level = "45" }, },
        { 13, { id = 107570, level = "60" }, },
        { 14, { id = 46968, level = "60" }, },
        { 15, { id = 118000, level = "60" }, },
        { 16, { id = 114028, level = "75" }, },
        { 17, { id = 114029, level = "75" }, },
        { 18, { id = 114030, level = "75" }, },
        { 20, { id = 107574, level = "90" }, },
        { 21, { id = 12292, level = "90" }, },
        { 22, { id = 46924, level = "90" }, },
        { 24, { id = 152278, level = "100" }, },
        { 25, { id = 152277, level = "100" }, },
        { 26, { id = 176289, level = "100" }, },
      },
      [WARRIOR_PROT_DIFF] = {
        { 1, { id = 103826, level = "15" }, },
        { 2, { id = 103827, level = "15" }, },
        { 3, { id = 103828, level = "15" }, },
        { 5, { id = 55694, level = "30" }, },
        { 6, { id = 29838, level = "30" }, },
        { 7, { id = 103840, level = "30" }, },
        { 9, { id = 169680, level = "45" }, },
        { 10, { id = 29725, level = "45" }, },
        { 11, { id = 169685, level = "45" }, },
        { 13, { id = 107570, level = "60" }, },
        { 14, { id = 46968, level = "60" }, },
        { 15, { id = 118000, level = "60" }, },
        { 16, { id = 114028, level = "75" }, },
        { 17, { id = 114029, level = "75" }, },
        { 18, { id = 114030, level = "75" }, },
        { 20, { id = 107574, level = "90" }, },
        { 21, { id = 12292, level = "90" }, },
        { 22, { id = 46924, level = "90" }, },
        { 24, { id = 152278, level = "100" }, },
        { 25, { id = 152277, level = "100" }, },
        { 26, { id = 152276, level = "100" }, },
      },
    },
    {
      name = "Glyphs (Major)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_majorwarrior",
      [GLYPH_DIFF] = {
        { 1, 58377 },
        { 2, 58367 },
        { 3, 94372 },
        { 4, 159701 },
        { 5, 63325 },
        { 6, 58386 },
        { 7, 58355 },
        { 8, 159761 },
        { 9, 58357 },
        { 10, 159708 },
        { 11, 58366 },
        { 12, 146970 },
        { 13, 58097 },
        { 14, 159738 },
        { 15, 58368 },
        { 16, 159740 },
        { 17, 58370 },
        { 18, 159754 },
        { 19, 94374 },
        { 20, 58356 },
        { 21, 58372 },
        { 22, 159759 },
        { 23, 58375 },
        { 24, 63329 },
        { 25, 63328 },
        { 26, 58384 },
        { 27, 159703 },
        { 28, 146971 },
        { 29, 58098 },
        { 30, 146965 },
        { 31, 58382 },
        { 32, 63324 },
      },
    },
    {
      name = "Glyphs (Minor)",
      CoinTexture = "texture:Interface\\Icons\\inv_glyph_minorwarrior",
      [GLYPH_DIFF] = {
        { 1, 58096 },
        { 2, 58369 },
        { 3, 115946 },
        { 4, 115943 },
        { 5, 58099 },
        { 6, 63327 },
        { 7, 58104 },
        { 8, 58095 },
        { 9, 123779 },
        { 10, 146968 },
        { 11, 146969 },
        { 12, 146973 },
        { 13, 146974 },
        { 14, 68164 },
      },
    },
  },
}

data["RACIALS"] = {
  name = "Racial Abilities",
  ContentType = RACIAL_CONTENT,
  TableType = SPELL_ITTYPE,
  items = {
    {
      name = "Blood Elf",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_bloodelf_male",
      [HORDE_RACIAL_DIFF] = {
        { 1, 154742 },
        { 2, 28877 },
        { 3, 822 },
        { 4, 28730 },
        { 5, { id = 50613, rank = colorstr("DEATHKNIGHT").."Death Knight" }, },
        { 6, { id = 80483, rank = colorstr("HUNTER").."Hunter" }, },
        { 7, { id = 129597, rank = colorstr("MONK").."Monk" }, },
        { 8, { id = 155145, rank = colorstr("PALADIN").."Paladin" }, },
        { 9, { id = 25046, rank = colorstr("ROGUE").."Rogue" }, },
        { 10, { id = 69179, rank = colorstr("WARRIOR").."Warrior" }, },
        { 12, 669 },
        { 13, 813 },
      },
    },
    {
      name = "Draenei",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_draenei_male",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 28875 },
        { 2, 121093 },
        { 3, 6562 },
        { 4, 59221 },
        { 6, 668 },
        { 7, 29932 },
      },
    },
    {
      name = "Dwarf",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_dwarf_male",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 92682 },
        { 2, 20596 },
        { 3, 59224 },
        { 4, 20594 },
        { 6, 668 },
        { 7, 672 },
      },
    },
    {
      name = "Gnome",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_gnome_male",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 20592 },
        { 2, 20593 },
        { 3, 20589 },
        { 4, 92680 },
        { 5, 20591 },
        { 6, { id = 154744, rank = colorstr("ROGUE").."Rogue" }, },
        { 7, { id = 154747, rank = colorstr("DEATHKNIGHT").."Death Knight" }, },
        { 8, { id = 154746, rank = colorstr("WARRIOR").."Warrior" }, },        
        { 10, 668 },
        { 11, 7340 },
      },
    },
    {
      name = "Goblin",
      CoinTexture = "texture:Interface\\Icons\\achievement_goblinhead",
      [HORDE_RACIAL_DIFF] = {
        { 1, 69044 },
        { 2, 69045 },
        { 3, 69046 },
        { 4, 69041 },
        { 5, 69070 },
        { 6, 69042 },
        { 8, 669 },
        { 9, 69269 },
      },
    },
    {
      name = "Human",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_human_male",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 20599 },
        { 2, 59752 },
        { 3, 20598 },
        { 5, 668 },
      },
    },
    {
      name = "Night Elf",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_nightelf_male",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 20583 },
        { 2, 20582 },
        { 3, 58984 },
        { 4, 154748 },
        { 5, 20585 },
        { 7, 668 },
        { 8, 671 },
      },
    },
    {
      name = "Orc",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_orc_male",
      [HORDE_RACIAL_DIFF] = {
        { 1, 20573 },
        { 2, { id = 20572, rank = colorstr("DEATHKNIGHT").."DK "..colorstr("HUNTER").."Hunter "..colorstr("ROGUE").."Rogue "..colorstr("WARRIOR").."Warrior" }, },
        { 3, { id = 33697, rank = colorstr("MONK").."Monk "..colorstr("SHAMAN").."Shaman" }, },
        { 4, { id = 33702, rank = colorstr("MAGE").."Mage "..colorstr("WARLOCK").."Warlock" }, },
        { 5, 21563 },
        { 7, 669 },
      },
    },
    {
      name = "Pandaren",
      CoinTexture = "texture:Interface\\Icons\\achievement_guild_classypanda",
      [BOTH_RACIAL_DIFF] = {
        { 1, 107076 },
        { 2, 107072 },
        { 3, 107073 },
        { 4, 107074 },
        { 5, 107079 },
        { 7, 669, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 8, 108131, [ATLASLOOT_IT_HORDE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 9, 668, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 10, 108130, [ATLASLOOT_IT_ALLIANCE] = true, [FACTION_INFO_IS_SET_ID] = true },
        { 11, 108127 },
      },
    },
    {
      name = "Tauren",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_tauren_male",
      [HORDE_RACIAL_DIFF] = {
        { 1, 154743 },
        { 2, 20552 },
        { 3, 20550 },
        { 4, 20551 },
        { 5, 20549 },
        { 7, 669 },
        { 8, 670 },
      },
    },
    {
      name = "Troll",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_troll_male",
      [HORDE_RACIAL_DIFF] = {
        { 1, 20557 },
        { 2, 26297 },
        { 3, 58943 },
        { 4, 20555 },
        { 6, 669 },
        { 7, 7341 },
      },
    },
    {
      name = "Undead",
      CoinTexture = "texture:Interface\\Icons\\achievement_character_undead_male",
      [HORDE_RACIAL_DIFF] = {
        { 1, 20577 },
        { 2, 20579 },
        { 3, 5227 },
        { 4, 7744 },
        { 6, 669 },
        { 7, 17737 },
      },
    },
    {
      name = "Worgen",
      CoinTexture = "texture:Interface\\Icons\\achievement_worganhead",
      [ALLIANCE_RACIAL_DIFF] = {
        { 1, 68976 },
        { 2, 94293 },
        { 3, 68992 },
        { 4, 68978 },
        { 5, 87840 },
        { 6, 68996 },
        { 7, 68975 },
        { 9, 668 },
        { 10, 69270 },
      },
    },
  },
}
